#! /bin/sh
#
#  install.gnu
#
#  Install all the GNU binaries, libraries and misc files.
#

# fail on errors
set -e

usage() {
  echo 'usage: install.gnu [-c]|[-l] <cdrom_path> <install_path>"' >&2
  echo '       -c:  copy files' >&2
  echo '       -l:  make symbolic links instead of copying' >&2
  echo '       cdrom_path: cdrom mount point, the default is "/cdrom"' >&2
  echo '       install_path: the default is "/usr/local"' >&2
  exit 1
}

FROM="/cdrom"
TO="/usr/local"

case $# in
  1) ;;
  2) FROM=$2;;
  3) FROM=$2; TO=$3;;
  *) usage;;
esac

case $1 in
  "-c")  CP="cp -p";;
  "-l")  CP="ln -s";;
  "*") usage;;
esac

# print commands as they are executed
set -x

if test ! -d $TO ; then mkdir -p $TO; fi
if test ! -d $TO/bin ; then mkdir -p $TO/bin; fi
$CP $FROM/usr/local/bin/'['  $TO/bin/'['
$CP $FROM/usr/local/bin/a2p  $TO/bin/a2p
$CP $FROM/usr/local/bin/ar  $TO/bin/ar
$CP $FROM/usr/local/bin/autoconf  $TO/bin/autoconf
$CP $FROM/usr/local/bin/basename  $TO/bin/basename
$CP $FROM/usr/local/bin/bash  $TO/bin/bash
$CP $FROM/usr/local/bin/bc  $TO/bin/bc
$CP $FROM/usr/local/bin/bdftops  $TO/bin/bdftops
$CP $FROM/usr/local/bin/bison  $TO/bin/bison
$CP $FROM/usr/local/bin/c++  $TO/bin/c++
$CP $FROM/usr/local/bin/c2ph  $TO/bin/c2ph
$CP $FROM/usr/local/bin/cat  $TO/bin/cat
$CP $FROM/usr/local/bin/chgrp  $TO/bin/chgrp
$CP $FROM/usr/local/bin/chmod  $TO/bin/chmod
$CP $FROM/usr/local/bin/chown  $TO/bin/chown
$CP $FROM/usr/local/bin/ci  $TO/bin/ci
$CP $FROM/usr/local/bin/cmp  $TO/bin/cmp
$CP $FROM/usr/local/bin/co  $TO/bin/co
$CP $FROM/usr/local/bin/comm  $TO/bin/comm
$CP $FROM/usr/local/bin/compress  $TO/bin/compress
$CP $FROM/usr/local/bin/cp  $TO/bin/cp
$CP $FROM/usr/local/bin/cpio  $TO/bin/cpio
$CP $FROM/usr/local/bin/cppstdin  $TO/bin/cppstdin
$CP $FROM/usr/local/bin/csplit  $TO/bin/csplit
$CP $FROM/usr/local/bin/ctags  $TO/bin/ctags
$CP $FROM/usr/local/bin/cut  $TO/bin/cut
$CP $FROM/usr/local/bin/cvs  $TO/bin/cvs
$CP $FROM/usr/local/bin/d  $TO/bin/d
$CP $FROM/usr/local/bin/date  $TO/bin/date
$CP $FROM/usr/local/bin/dd  $TO/bin/dd
$CP $FROM/usr/local/bin/df  $TO/bin/df
$CP $FROM/usr/local/bin/diff  $TO/bin/diff
$CP $FROM/usr/local/bin/diff3  $TO/bin/diff3
$CP $FROM/usr/local/bin/dir  $TO/bin/dir
$CP $FROM/usr/local/bin/dirname  $TO/bin/dirname
$CP $FROM/usr/local/bin/du  $TO/bin/du
$CP $FROM/usr/local/bin/echo  $TO/bin/echo
$CP $FROM/usr/local/bin/egrep  $TO/bin/egrep
$CP $FROM/usr/local/bin/emacs  $TO/bin/emacs
$CP $FROM/usr/local/bin/emacsclient  $TO/bin/emacsclient
$CP $FROM/usr/local/bin/env  $TO/bin/env
$CP $FROM/usr/local/bin/etags  $TO/bin/etags
$CP $FROM/usr/local/bin/expand  $TO/bin/expand
$CP $FROM/usr/local/bin/expr  $TO/bin/expr
$CP $FROM/usr/local/bin/f2c  $TO/bin/f2c
$CP $FROM/usr/local/bin/false  $TO/bin/false
$CP $FROM/usr/local/bin/fgrep  $TO/bin/fgrep
$CP $FROM/usr/local/bin/find  $TO/bin/find
$CP $FROM/usr/local/bin/find2perl  $TO/bin/find2perl
$CP $FROM/usr/local/bin/flex  $TO/bin/flex
$CP $FROM/usr/local/bin/fold  $TO/bin/fold
$CP $FROM/usr/local/bin/font2c  $TO/bin/font2c
$CP $FROM/usr/local/bin/g++  $TO/bin/g++
$CP $FROM/usr/local/bin/gas  $TO/bin/gas
$CP $FROM/usr/local/bin/gawk  $TO/bin/gawk
$CP $FROM/usr/local/bin/gcc  $TO/bin/gcc
$CP $FROM/usr/local/bin/gdb  $TO/bin/gdb
$CP $FROM/usr/local/bin/gnuplot  $TO/bin/gnuplot
$CP $FROM/usr/local/bin/gnuplot_x11  $TO/bin/gnuplot_x11
$CP $FROM/usr/local/bin/gprof  $TO/bin/gprof
$CP $FROM/usr/local/bin/gptx  $TO/bin/gptx
$CP $FROM/usr/local/bin/graph  $TO/bin/graph
$CP $FROM/usr/local/bin/grep  $TO/bin/grep
$CP $FROM/usr/local/bin/groups  $TO/bin/groups
$CP $FROM/usr/local/bin/gs  $TO/bin/gs
$CP $FROM/usr/local/bin/gsbj  $TO/bin/gsbj
$CP $FROM/usr/local/bin/gsdj  $TO/bin/gsdj
$CP $FROM/usr/local/bin/gslj  $TO/bin/gslj
$CP $FROM/usr/local/bin/gslp  $TO/bin/gslp
$CP $FROM/usr/local/bin/gsnd  $TO/bin/gsnd
$CP $FROM/usr/local/bin/h2ph  $TO/bin/h2ph
$CP $FROM/usr/local/bin/head  $TO/bin/head
$CP $FROM/usr/local/bin/hello  $TO/bin/hello
$CP $FROM/usr/local/bin/id  $TO/bin/id
$CP $FROM/usr/local/bin/ident  $TO/bin/ident
$CP $FROM/usr/local/bin/indent  $TO/bin/indent
$CP $FROM/usr/local/bin/info  $TO/bin/info
$CP $FROM/usr/local/bin/install  $TO/bin/install
$CP $FROM/usr/local/bin/isexpand  $TO/bin/isexpand
$CP $FROM/usr/local/bin/ispell  $TO/bin/ispell
$CP $FROM/usr/local/bin/jargon  $TO/bin/jargon
$CP $FROM/usr/local/bin/join  $TO/bin/join
$CP $FROM/usr/local/bin/lasergnu  $TO/bin/lasergnu
$CP $FROM/usr/local/bin/ld  $TO/bin/ld
$CP $FROM/usr/local/bin/less  $TO/bin/less
$CP $FROM/usr/local/bin/less.hlp  $TO/bin/less.hlp
$CP $FROM/usr/local/bin/lesskey  $TO/bin/lesskey
$CP $FROM/usr/local/bin/ln  $TO/bin/ln
$CP $FROM/usr/local/bin/locate  $TO/bin/locate
$CP $FROM/usr/local/bin/logname  $TO/bin/logname
$CP $FROM/usr/local/bin/ls  $TO/bin/ls
$CP $FROM/usr/local/bin/m4  $TO/bin/m4
$CP $FROM/usr/local/bin/make  $TO/bin/make
$CP $FROM/usr/local/bin/makeinfo  $TO/bin/makeinfo
$CP $FROM/usr/local/bin/merge  $TO/bin/merge
$CP $FROM/usr/local/bin/mkdir  $TO/bin/mkdir
$CP $FROM/usr/local/bin/mkfifo  $TO/bin/mkfifo
$CP $FROM/usr/local/bin/mkmodules  $TO/bin/mkmodules
$CP $FROM/usr/local/bin/mknod  $TO/bin/mknod
$CP $FROM/usr/local/bin/mt  $TO/bin/mt
$CP $FROM/usr/local/bin/munchlist  $TO/bin/munchlist
$CP $FROM/usr/local/bin/mv  $TO/bin/mv
$CP $FROM/usr/local/bin/nice  $TO/bin/nice
$CP $FROM/usr/local/bin/nl  $TO/bin/nl
$CP $FROM/usr/local/bin/nm  $TO/bin/nm
$CP $FROM/usr/local/bin/nohup  $TO/bin/nohup
$CP $FROM/usr/local/bin/objdump  $TO/bin/objdump
$CP $FROM/usr/local/bin/paste  $TO/bin/paste
$CP $FROM/usr/local/bin/patch  $TO/bin/patch
$CP $FROM/usr/local/bin/pathchk  $TO/bin/pathchk
$CP $FROM/usr/local/bin/perl  $TO/bin/perl
$CP $FROM/usr/local/bin/plot2fig  $TO/bin/plot2fig
$CP $FROM/usr/local/bin/plot2plot  $TO/bin/plot2plot
$CP $FROM/usr/local/bin/plot2ps  $TO/bin/plot2ps
$CP $FROM/usr/local/bin/plot2tek  $TO/bin/plot2tek
$CP $FROM/usr/local/bin/pr  $TO/bin/pr
$CP $FROM/usr/local/bin/printenv  $TO/bin/printenv
$CP $FROM/usr/local/bin/printf  $TO/bin/printf
$CP $FROM/usr/local/bin/protoize  $TO/bin/protoize
$CP $FROM/usr/local/bin/pstruct  $TO/bin/pstruct
$CP $FROM/usr/local/bin/ptx  $TO/bin/ptx
$CP $FROM/usr/local/bin/ranlib  $TO/bin/ranlib
$CP $FROM/usr/local/bin/rcs  $TO/bin/rcs
$CP $FROM/usr/local/bin/rcsdiff  $TO/bin/rcsdiff
$CP $FROM/usr/local/bin/rcsmerge  $TO/bin/rcsmerge
$CP $FROM/usr/local/bin/recode  $TO/bin/recode
$CP $FROM/usr/local/bin/rlog  $TO/bin/rlog
$CP $FROM/usr/local/bin/rm  $TO/bin/rm
$CP $FROM/usr/local/bin/rmdir  $TO/bin/rmdir
$CP $FROM/usr/local/bin/rmt  $TO/bin/rmt
$CP $FROM/usr/local/bin/s2p  $TO/bin/s2p
$CP $FROM/usr/local/bin/screen  $TO/bin/screen
$CP $FROM/usr/local/bin/sdiff  $TO/bin/sdiff
$CP $FROM/usr/local/bin/sed  $TO/bin/sed
$CP $FROM/usr/local/bin/size  $TO/bin/size
$CP $FROM/usr/local/bin/sleep  $TO/bin/sleep
$CP $FROM/usr/local/bin/sort  $TO/bin/sort
$CP $FROM/usr/local/bin/split  $TO/bin/split
$CP $FROM/usr/local/bin/strip  $TO/bin/strip
$CP $FROM/usr/local/bin/stty  $TO/bin/stty
$CP $FROM/usr/local/bin/su  $TO/bin/su
$CP $FROM/usr/local/bin/sum  $TO/bin/sum
$CP $FROM/usr/local/bin/tac  $TO/bin/tac
$CP $FROM/usr/local/bin/tail  $TO/bin/tail
$CP $FROM/usr/local/bin/taintperl  $TO/bin/taintperl
$CP $FROM/usr/local/bin/tar  $TO/bin/tar
$CP $FROM/usr/local/bin/tee  $TO/bin/tee
$CP $FROM/usr/local/bin/tek2plot  $TO/bin/tek2plot
$CP $FROM/usr/local/bin/test  $TO/bin/test
$CP $FROM/usr/local/bin/texi2roff  $TO/bin/texi2roff
$CP $FROM/usr/local/bin/texindex  $TO/bin/texindex
$CP $FROM/usr/local/bin/time  $TO/bin/time
$CP $FROM/usr/local/bin/touch  $TO/bin/touch
$CP $FROM/usr/local/bin/tput  $TO/bin/tput
$CP $FROM/usr/local/bin/tr  $TO/bin/tr
$CP $FROM/usr/local/bin/true  $TO/bin/true
$CP $FROM/usr/local/bin/tty  $TO/bin/tty
$CP $FROM/usr/local/bin/uname  $TO/bin/uname
$CP $FROM/usr/local/bin/uncompress  $TO/bin/uncompress
$CP $FROM/usr/local/bin/unexpand  $TO/bin/unexpand
$CP $FROM/usr/local/bin/uniq  $TO/bin/uniq
$CP $FROM/usr/local/bin/unprotoize  $TO/bin/unprotoize
$CP $FROM/usr/local/bin/uucp  $TO/bin/uucp
$CP $FROM/usr/local/bin/uulog  $TO/bin/uulog
$CP $FROM/usr/local/bin/uuname  $TO/bin/uuname
$CP $FROM/usr/local/bin/uustat  $TO/bin/uustat
$CP $FROM/usr/local/bin/uux  $TO/bin/uux
$CP $FROM/usr/local/bin/v  $TO/bin/v
$CP $FROM/usr/local/bin/vdir  $TO/bin/vdir
$CP $FROM/usr/local/bin/wc  $TO/bin/wc
$CP $FROM/usr/local/bin/wdiff  $TO/bin/wdiff
$CP $FROM/usr/local/bin/who  $TO/bin/who
$CP $FROM/usr/local/bin/whoami  $TO/bin/whoami
$CP $FROM/usr/local/bin/xargs  $TO/bin/xargs
$CP $FROM/usr/local/bin/xplot  $TO/bin/xplot
$CP $FROM/usr/local/bin/yes  $TO/bin/yes
$CP $FROM/usr/local/bin/zcat  $TO/bin/zcat
if test ! -d $TO/emacs ; then mkdir -p $TO/emacs; fi
if test ! -d $TO/emacs/etc ; then mkdir -p $TO/emacs/etc; fi
$CP $FROM/usr/local/emacs/etc/3B-MAXMEM  $TO/emacs/etc/3B-MAXMEM
$CP $FROM/usr/local/emacs/etc/AIX.DUMP  $TO/emacs/etc/AIX.DUMP
$CP $FROM/usr/local/emacs/etc/APOLLO  $TO/emacs/etc/APOLLO
$CP $FROM/usr/local/emacs/etc/APPLE  $TO/emacs/etc/APPLE
$CP $FROM/usr/local/emacs/etc/BABYL  $TO/emacs/etc/BABYL
$CP $FROM/usr/local/emacs/etc/CCADIFF  $TO/emacs/etc/CCADIFF
$CP $FROM/usr/local/emacs/etc/CHARACTERS  $TO/emacs/etc/CHARACTERS
$CP $FROM/usr/local/emacs/etc/COOKIES  $TO/emacs/etc/COOKIES
$CP $FROM/usr/local/emacs/etc/COPYING  $TO/emacs/etc/COPYING
$CP $FROM/usr/local/emacs/etc/ChangeLog  $TO/emacs/etc/ChangeLog
$CP $FROM/usr/local/emacs/etc/DEBUG  $TO/emacs/etc/DEBUG
$CP $FROM/usr/local/emacs/etc/DIFF  $TO/emacs/etc/DIFF
$CP $FROM/usr/local/emacs/etc/DISTRIB  $TO/emacs/etc/DISTRIB
$CP $FROM/usr/local/emacs/etc/DOC  $TO/emacs/etc/DOC
$CP $FROM/usr/local/emacs/etc/DOC-18.59.1  $TO/emacs/etc/DOC-18.59.1
$CP $FROM/usr/local/emacs/etc/DOC-18.59.2  $TO/emacs/etc/DOC-18.59.2
$CP $FROM/usr/local/emacs/etc/FAQ  $TO/emacs/etc/FAQ
$CP $FROM/usr/local/emacs/etc/FTP  $TO/emacs/etc/FTP
$CP $FROM/usr/local/emacs/etc/GNU  $TO/emacs/etc/GNU
$CP $FROM/usr/local/emacs/etc/GNU.JOKES  $TO/emacs/etc/GNU.JOKES
$CP $FROM/usr/local/emacs/etc/GOSDIFF  $TO/emacs/etc/GOSDIFF
$CP $FROM/usr/local/emacs/etc/INTERVAL.IDEAS  $TO/emacs/etc/INTERVAL.IDEAS
$CP $FROM/usr/local/emacs/etc/INTERVIEW  $TO/emacs/etc/INTERVIEW
$CP $FROM/usr/local/emacs/etc/LEDIT  $TO/emacs/etc/LEDIT
$CP $FROM/usr/local/emacs/etc/LPF  $TO/emacs/etc/LPF
$CP $FROM/usr/local/emacs/etc/MACHINES  $TO/emacs/etc/MACHINES
$CP $FROM/usr/local/emacs/etc/MAILINGLISTS  $TO/emacs/etc/MAILINGLISTS
$CP $FROM/usr/local/emacs/etc/MOTIVATION  $TO/emacs/etc/MOTIVATION
$CP $FROM/usr/local/emacs/etc/Makefile  $TO/emacs/etc/Makefile
$CP $FROM/usr/local/emacs/etc/NEWS  $TO/emacs/etc/NEWS
$CP $FROM/usr/local/emacs/etc/NICKLES.WORTH  $TO/emacs/etc/NICKLES.WORTH
$CP $FROM/usr/local/emacs/etc/ONEWS  $TO/emacs/etc/ONEWS
$CP $FROM/usr/local/emacs/etc/OONEWS  $TO/emacs/etc/OONEWS
$CP $FROM/usr/local/emacs/etc/OPTIONS  $TO/emacs/etc/OPTIONS
$CP $FROM/usr/local/emacs/etc/README  $TO/emacs/etc/README
$CP $FROM/usr/local/emacs/etc/SERVICE  $TO/emacs/etc/SERVICE
$CP $FROM/usr/local/emacs/etc/SUN-SUPPORT  $TO/emacs/etc/SUN-SUPPORT
$CP $FROM/usr/local/emacs/etc/SUNBUG  $TO/emacs/etc/SUNBUG
$CP $FROM/usr/local/emacs/etc/TERMS  $TO/emacs/etc/TERMS
$CP $FROM/usr/local/emacs/etc/TO-DO  $TO/emacs/etc/TO-DO
$CP $FROM/usr/local/emacs/etc/TUTORIAL  $TO/emacs/etc/TUTORIAL
$CP $FROM/usr/local/emacs/etc/XDOC  $TO/emacs/etc/XDOC
$CP $FROM/usr/local/emacs/etc/XENIX  $TO/emacs/etc/XENIX
$CP $FROM/usr/local/emacs/etc/Xkeymap.txt  $TO/emacs/etc/Xkeymap.txt
$CP $FROM/usr/local/emacs/etc/celibacy.1  $TO/emacs/etc/celibacy.1
$CP $FROM/usr/local/emacs/etc/complink.com  $TO/emacs/etc/complink.com
$CP $FROM/usr/local/emacs/etc/ctags  $TO/emacs/etc/ctags
$CP $FROM/usr/local/emacs/etc/cvtmail  $TO/emacs/etc/cvtmail
$CP $FROM/usr/local/emacs/etc/cvtmail.c  $TO/emacs/etc/cvtmail.c
$CP $FROM/usr/local/emacs/etc/digest-doc  $TO/emacs/etc/digest-doc
$CP $FROM/usr/local/emacs/etc/digest-doc.c  $TO/emacs/etc/digest-doc.c
$CP $FROM/usr/local/emacs/etc/echo.msg  $TO/emacs/etc/echo.msg
$CP $FROM/usr/local/emacs/etc/emacs.1  $TO/emacs/etc/emacs.1
$CP $FROM/usr/local/emacs/etc/emacs.icon  $TO/emacs/etc/emacs.icon
$CP $FROM/usr/local/emacs/etc/emacs.names  $TO/emacs/etc/emacs.names
$CP $FROM/usr/local/emacs/etc/emacsclient  $TO/emacs/etc/emacsclient
$CP $FROM/usr/local/emacs/etc/emacsclient.c  $TO/emacs/etc/emacsclient.c
$CP $FROM/usr/local/emacs/etc/emacstool.1  $TO/emacs/etc/emacstool.1
$CP $FROM/usr/local/emacs/etc/emacstool.c  $TO/emacs/etc/emacstool.c
$CP $FROM/usr/local/emacs/etc/env  $TO/emacs/etc/env
$CP $FROM/usr/local/emacs/etc/env.c  $TO/emacs/etc/env.c
$CP $FROM/usr/local/emacs/etc/etags  $TO/emacs/etc/etags
$CP $FROM/usr/local/emacs/etc/etags-vmslib.c  $TO/emacs/etc/etags-vmslib.c
$CP $FROM/usr/local/emacs/etc/etags.c  $TO/emacs/etc/etags.c
$CP $FROM/usr/local/emacs/etc/etags.vms  $TO/emacs/etc/etags.vms
$CP $FROM/usr/local/emacs/etc/fakemail  $TO/emacs/etc/fakemail
$CP $FROM/usr/local/emacs/etc/fakemail.c  $TO/emacs/etc/fakemail.c
$CP $FROM/usr/local/emacs/etc/faq2texi.perl  $TO/emacs/etc/faq2texi.perl
$CP $FROM/usr/local/emacs/etc/ledit.l  $TO/emacs/etc/ledit.l
$CP $FROM/usr/local/emacs/etc/leditcfns.c  $TO/emacs/etc/leditcfns.c
$CP $FROM/usr/local/emacs/etc/make-docfile  $TO/emacs/etc/make-docfile
$CP $FROM/usr/local/emacs/etc/make-docfile.c  $TO/emacs/etc/make-docfile.c
$CP $FROM/usr/local/emacs/etc/makedoc.com  $TO/emacs/etc/makedoc.com
$CP $FROM/usr/local/emacs/etc/movemail  $TO/emacs/etc/movemail
$CP $FROM/usr/local/emacs/etc/movemail.c  $TO/emacs/etc/movemail.c
$CP $FROM/usr/local/emacs/etc/ms-kermit  $TO/emacs/etc/ms-kermit
$CP $FROM/usr/local/emacs/etc/ms-kermit-7bit  $TO/emacs/etc/ms-kermit-7bit
$CP $FROM/usr/local/emacs/etc/qsort.c  $TO/emacs/etc/qsort.c
$CP $FROM/usr/local/emacs/etc/refcard.tex  $TO/emacs/etc/refcard.tex
$CP $FROM/usr/local/emacs/etc/server  $TO/emacs/etc/server
$CP $FROM/usr/local/emacs/etc/server.c  $TO/emacs/etc/server.c
$CP $FROM/usr/local/emacs/etc/sex.6  $TO/emacs/etc/sex.6
$CP $FROM/usr/local/emacs/etc/sorted-doc  $TO/emacs/etc/sorted-doc
$CP $FROM/usr/local/emacs/etc/sorted-doc.c  $TO/emacs/etc/sorted-doc.c
$CP $FROM/usr/local/emacs/etc/spook.lines  $TO/emacs/etc/spook.lines
$CP $FROM/usr/local/emacs/etc/termcap.dat  $TO/emacs/etc/termcap.dat
$CP $FROM/usr/local/emacs/etc/termcap.ucb  $TO/emacs/etc/termcap.ucb
$CP $FROM/usr/local/emacs/etc/test-distrib  $TO/emacs/etc/test-distrib
$CP $FROM/usr/local/emacs/etc/test-distrib.c  $TO/emacs/etc/test-distrib.c
$CP $FROM/usr/local/emacs/etc/testfile  $TO/emacs/etc/testfile
$CP $FROM/usr/local/emacs/etc/ulimit.hack  $TO/emacs/etc/ulimit.hack
$CP $FROM/usr/local/emacs/etc/vipcard.tex  $TO/emacs/etc/vipcard.tex
$CP $FROM/usr/local/emacs/etc/vmslink.opt  $TO/emacs/etc/vmslink.opt
$CP $FROM/usr/local/emacs/etc/wakeup  $TO/emacs/etc/wakeup
$CP $FROM/usr/local/emacs/etc/wakeup.c  $TO/emacs/etc/wakeup.c
$CP $FROM/usr/local/emacs/etc/xmouse.doc  $TO/emacs/etc/xmouse.doc
$CP $FROM/usr/local/emacs/etc/yow  $TO/emacs/etc/yow
$CP $FROM/usr/local/emacs/etc/yow.c  $TO/emacs/etc/yow.c
$CP $FROM/usr/local/emacs/etc/yow.lines  $TO/emacs/etc/yow.lines
if test ! -d $TO/emacs/info ; then mkdir -p $TO/emacs/info; fi
$CP $FROM/usr/local/emacs/info/COPYING  $TO/emacs/info/COPYING
$CP $FROM/usr/local/emacs/info/dir  $TO/emacs/info/dir
$CP $FROM/usr/local/emacs/info/emacs  $TO/emacs/info/emacs
$CP $FROM/usr/local/emacs/info/emacs-1  $TO/emacs/info/emacs-1
$CP $FROM/usr/local/emacs/info/emacs-10  $TO/emacs/info/emacs-10
$CP $FROM/usr/local/emacs/info/emacs-11  $TO/emacs/info/emacs-11
$CP $FROM/usr/local/emacs/info/emacs-12  $TO/emacs/info/emacs-12
$CP $FROM/usr/local/emacs/info/emacs-13  $TO/emacs/info/emacs-13
$CP $FROM/usr/local/emacs/info/emacs-14  $TO/emacs/info/emacs-14
$CP $FROM/usr/local/emacs/info/emacs-15  $TO/emacs/info/emacs-15
$CP $FROM/usr/local/emacs/info/emacs-16  $TO/emacs/info/emacs-16
$CP $FROM/usr/local/emacs/info/emacs-17  $TO/emacs/info/emacs-17
$CP $FROM/usr/local/emacs/info/emacs-18  $TO/emacs/info/emacs-18
$CP $FROM/usr/local/emacs/info/emacs-19  $TO/emacs/info/emacs-19
$CP $FROM/usr/local/emacs/info/emacs-2  $TO/emacs/info/emacs-2
$CP $FROM/usr/local/emacs/info/emacs-3  $TO/emacs/info/emacs-3
$CP $FROM/usr/local/emacs/info/emacs-4  $TO/emacs/info/emacs-4
$CP $FROM/usr/local/emacs/info/emacs-5  $TO/emacs/info/emacs-5
$CP $FROM/usr/local/emacs/info/emacs-6  $TO/emacs/info/emacs-6
$CP $FROM/usr/local/emacs/info/emacs-7  $TO/emacs/info/emacs-7
$CP $FROM/usr/local/emacs/info/emacs-8  $TO/emacs/info/emacs-8
$CP $FROM/usr/local/emacs/info/emacs-9  $TO/emacs/info/emacs-9
$CP $FROM/usr/local/emacs/info/info  $TO/emacs/info/info
$CP $FROM/usr/local/emacs/info/regex  $TO/emacs/info/regex
$CP $FROM/usr/local/emacs/info/termcap  $TO/emacs/info/termcap
$CP $FROM/usr/local/emacs/info/termcap-1  $TO/emacs/info/termcap-1
$CP $FROM/usr/local/emacs/info/termcap-2  $TO/emacs/info/termcap-2
$CP $FROM/usr/local/emacs/info/termcap-3  $TO/emacs/info/termcap-3
$CP $FROM/usr/local/emacs/info/texinfo  $TO/emacs/info/texinfo
$CP $FROM/usr/local/emacs/info/texinfo-1  $TO/emacs/info/texinfo-1
$CP $FROM/usr/local/emacs/info/texinfo-2  $TO/emacs/info/texinfo-2
$CP $FROM/usr/local/emacs/info/texinfo-3  $TO/emacs/info/texinfo-3
$CP $FROM/usr/local/emacs/info/texinfo-4  $TO/emacs/info/texinfo-4
$CP $FROM/usr/local/emacs/info/vip  $TO/emacs/info/vip
$CP $FROM/usr/local/emacs/info/vip-1  $TO/emacs/info/vip-1
$CP $FROM/usr/local/emacs/info/vip-2  $TO/emacs/info/vip-2
if test ! -d $TO/emacs/lisp ; then mkdir -p $TO/emacs/lisp; fi
$CP $FROM/usr/local/emacs/lisp/COPYING  $TO/emacs/lisp/COPYING
$CP $FROM/usr/local/emacs/lisp/ChangeLog  $TO/emacs/lisp/ChangeLog
$CP $FROM/usr/local/emacs/lisp/abbrev.el  $TO/emacs/lisp/abbrev.el
$CP $FROM/usr/local/emacs/lisp/abbrev.elc  $TO/emacs/lisp/abbrev.elc
$CP $FROM/usr/local/emacs/lisp/abbrevlist.el  $TO/emacs/lisp/abbrevlist.el
$CP $FROM/usr/local/emacs/lisp/abbrevlist.elc  $TO/emacs/lisp/abbrevlist.elc
$CP $FROM/usr/local/emacs/lisp/ada.el  $TO/emacs/lisp/ada.el
$CP $FROM/usr/local/emacs/lisp/ada.elc  $TO/emacs/lisp/ada.elc
$CP $FROM/usr/local/emacs/lisp/add-log.el  $TO/emacs/lisp/add-log.el
$CP $FROM/usr/local/emacs/lisp/add-log.elc  $TO/emacs/lisp/add-log.elc
$CP $FROM/usr/local/emacs/lisp/autoinsert.el  $TO/emacs/lisp/autoinsert.el
$CP $FROM/usr/local/emacs/lisp/backquote.el  $TO/emacs/lisp/backquote.el
$CP $FROM/usr/local/emacs/lisp/backquote.elc  $TO/emacs/lisp/backquote.elc
$CP $FROM/usr/local/emacs/lisp/bg-mouse.el  $TO/emacs/lisp/bg-mouse.el
$CP $FROM/usr/local/emacs/lisp/bibtex.el  $TO/emacs/lisp/bibtex.el
$CP $FROM/usr/local/emacs/lisp/bibtex.elc  $TO/emacs/lisp/bibtex.elc
$CP $FROM/usr/local/emacs/lisp/blackbox.el  $TO/emacs/lisp/blackbox.el
$CP $FROM/usr/local/emacs/lisp/blackbox.elc  $TO/emacs/lisp/blackbox.elc
$CP $FROM/usr/local/emacs/lisp/buff-menu.el  $TO/emacs/lisp/buff-menu.el
$CP $FROM/usr/local/emacs/lisp/buff-menu.elc  $TO/emacs/lisp/buff-menu.elc
$CP $FROM/usr/local/emacs/lisp/bytecomp.el  $TO/emacs/lisp/bytecomp.el
$CP $FROM/usr/local/emacs/lisp/bytecomp.elc  $TO/emacs/lisp/bytecomp.elc
$CP $FROM/usr/local/emacs/lisp/c-fill.el  $TO/emacs/lisp/c-fill.el
$CP $FROM/usr/local/emacs/lisp/c-fill.elc  $TO/emacs/lisp/c-fill.elc
$CP $FROM/usr/local/emacs/lisp/c-mode.el  $TO/emacs/lisp/c-mode.el
$CP $FROM/usr/local/emacs/lisp/c-mode.elc  $TO/emacs/lisp/c-mode.elc
$CP $FROM/usr/local/emacs/lisp/cal.el  $TO/emacs/lisp/cal.el
$CP $FROM/usr/local/emacs/lisp/cal.elc  $TO/emacs/lisp/cal.elc
$CP $FROM/usr/local/emacs/lisp/chistory.el  $TO/emacs/lisp/chistory.el
$CP $FROM/usr/local/emacs/lisp/chistory.elc  $TO/emacs/lisp/chistory.elc
$CP $FROM/usr/local/emacs/lisp/cl-indent.el  $TO/emacs/lisp/cl-indent.el
$CP $FROM/usr/local/emacs/lisp/cl-indent.elc  $TO/emacs/lisp/cl-indent.elc
$CP $FROM/usr/local/emacs/lisp/cl.el  $TO/emacs/lisp/cl.el
$CP $FROM/usr/local/emacs/lisp/cl.elc  $TO/emacs/lisp/cl.elc
$CP $FROM/usr/local/emacs/lisp/cmacexp.el  $TO/emacs/lisp/cmacexp.el
$CP $FROM/usr/local/emacs/lisp/compare-w.el  $TO/emacs/lisp/compare-w.el
$CP $FROM/usr/local/emacs/lisp/compare-w.elc  $TO/emacs/lisp/compare-w.elc
$CP $FROM/usr/local/emacs/lisp/compile.el  $TO/emacs/lisp/compile.el
$CP $FROM/usr/local/emacs/lisp/compile.elc  $TO/emacs/lisp/compile.elc
$CP $FROM/usr/local/emacs/lisp/dabbrev.el  $TO/emacs/lisp/dabbrev.el
$CP $FROM/usr/local/emacs/lisp/dabbrev.elc  $TO/emacs/lisp/dabbrev.elc
$CP $FROM/usr/local/emacs/lisp/dbx.el  $TO/emacs/lisp/dbx.el
$CP $FROM/usr/local/emacs/lisp/dbx.elc  $TO/emacs/lisp/dbx.elc
$CP $FROM/usr/local/emacs/lisp/debug.el  $TO/emacs/lisp/debug.el
$CP $FROM/usr/local/emacs/lisp/debug.elc  $TO/emacs/lisp/debug.elc
$CP $FROM/usr/local/emacs/lisp/dired.el  $TO/emacs/lisp/dired.el
$CP $FROM/usr/local/emacs/lisp/dired.elc  $TO/emacs/lisp/dired.elc
$CP $FROM/usr/local/emacs/lisp/disass.el  $TO/emacs/lisp/disass.el
$CP $FROM/usr/local/emacs/lisp/disass.elc  $TO/emacs/lisp/disass.elc
$CP $FROM/usr/local/emacs/lisp/dissociate.el  $TO/emacs/lisp/dissociate.el
$CP $FROM/usr/local/emacs/lisp/dissociate.elc  $TO/emacs/lisp/dissociate.elc
$CP $FROM/usr/local/emacs/lisp/doctex.el  $TO/emacs/lisp/doctex.el
$CP $FROM/usr/local/emacs/lisp/doctor.el  $TO/emacs/lisp/doctor.el
$CP $FROM/usr/local/emacs/lisp/doctor.elc  $TO/emacs/lisp/doctor.elc
$CP $FROM/usr/local/emacs/lisp/ebuff-menu.el  $TO/emacs/lisp/ebuff-menu.el
$CP $FROM/usr/local/emacs/lisp/ebuff-menu.elc  $TO/emacs/lisp/ebuff-menu.elc
$CP $FROM/usr/local/emacs/lisp/echistory.el  $TO/emacs/lisp/echistory.el
$CP $FROM/usr/local/emacs/lisp/echistory.elc  $TO/emacs/lisp/echistory.elc
$CP $FROM/usr/local/emacs/lisp/edt-doc.el  $TO/emacs/lisp/edt-doc.el
$CP $FROM/usr/local/emacs/lisp/edt.el  $TO/emacs/lisp/edt.el
$CP $FROM/usr/local/emacs/lisp/edt.elc  $TO/emacs/lisp/edt.elc
$CP $FROM/usr/local/emacs/lisp/ehelp.el  $TO/emacs/lisp/ehelp.el
$CP $FROM/usr/local/emacs/lisp/ehelp.elc  $TO/emacs/lisp/ehelp.elc
$CP $FROM/usr/local/emacs/lisp/electric.el  $TO/emacs/lisp/electric.el
$CP $FROM/usr/local/emacs/lisp/electric.elc  $TO/emacs/lisp/electric.elc
$CP $FROM/usr/local/emacs/lisp/emacsbug.el  $TO/emacs/lisp/emacsbug.el
$CP $FROM/usr/local/emacs/lisp/files.el  $TO/emacs/lisp/files.el
$CP $FROM/usr/local/emacs/lisp/files.elc  $TO/emacs/lisp/files.elc
$CP $FROM/usr/local/emacs/lisp/fill.el  $TO/emacs/lisp/fill.el
$CP $FROM/usr/local/emacs/lisp/fill.elc  $TO/emacs/lisp/fill.elc
$CP $FROM/usr/local/emacs/lisp/flame.el  $TO/emacs/lisp/flame.el
$CP $FROM/usr/local/emacs/lisp/flame.elc  $TO/emacs/lisp/flame.elc
$CP $FROM/usr/local/emacs/lisp/float.el  $TO/emacs/lisp/float.el
$CP $FROM/usr/local/emacs/lisp/float.elc  $TO/emacs/lisp/float.elc
$CP $FROM/usr/local/emacs/lisp/fortran.el  $TO/emacs/lisp/fortran.el
$CP $FROM/usr/local/emacs/lisp/fortran.elc  $TO/emacs/lisp/fortran.elc
$CP $FROM/usr/local/emacs/lisp/ftp.el  $TO/emacs/lisp/ftp.el
$CP $FROM/usr/local/emacs/lisp/ftp.elc  $TO/emacs/lisp/ftp.elc
$CP $FROM/usr/local/emacs/lisp/gdb.el  $TO/emacs/lisp/gdb.el
$CP $FROM/usr/local/emacs/lisp/gdb.elc  $TO/emacs/lisp/gdb.elc
$CP $FROM/usr/local/emacs/lisp/gosmacs.el  $TO/emacs/lisp/gosmacs.el
$CP $FROM/usr/local/emacs/lisp/grow-vers.el  $TO/emacs/lisp/grow-vers.el
$CP $FROM/usr/local/emacs/lisp/hanoi.el  $TO/emacs/lisp/hanoi.el
$CP $FROM/usr/local/emacs/lisp/hanoi.elc  $TO/emacs/lisp/hanoi.elc
$CP $FROM/usr/local/emacs/lisp/help.el  $TO/emacs/lisp/help.el
$CP $FROM/usr/local/emacs/lisp/help.elc  $TO/emacs/lisp/help.elc
$CP $FROM/usr/local/emacs/lisp/helper.el  $TO/emacs/lisp/helper.el
$CP $FROM/usr/local/emacs/lisp/helper.elc  $TO/emacs/lisp/helper.elc
$CP $FROM/usr/local/emacs/lisp/hideif.el  $TO/emacs/lisp/hideif.el
$CP $FROM/usr/local/emacs/lisp/hideif.elc  $TO/emacs/lisp/hideif.elc
$CP $FROM/usr/local/emacs/lisp/icon.el  $TO/emacs/lisp/icon.el
$CP $FROM/usr/local/emacs/lisp/icon.elc  $TO/emacs/lisp/icon.elc
$CP $FROM/usr/local/emacs/lisp/inc-vers.el  $TO/emacs/lisp/inc-vers.el
$CP $FROM/usr/local/emacs/lisp/indent.el  $TO/emacs/lisp/indent.el
$CP $FROM/usr/local/emacs/lisp/indent.elc  $TO/emacs/lisp/indent.elc
$CP $FROM/usr/local/emacs/lisp/info.el  $TO/emacs/lisp/info.el
$CP $FROM/usr/local/emacs/lisp/info.elc  $TO/emacs/lisp/info.elc
$CP $FROM/usr/local/emacs/lisp/informat.el  $TO/emacs/lisp/informat.el
$CP $FROM/usr/local/emacs/lisp/informat.elc  $TO/emacs/lisp/informat.elc
$CP $FROM/usr/local/emacs/lisp/isearch.el  $TO/emacs/lisp/isearch.el
$CP $FROM/usr/local/emacs/lisp/isearch.elc  $TO/emacs/lisp/isearch.elc
$CP $FROM/usr/local/emacs/lisp/kermit.el  $TO/emacs/lisp/kermit.el
$CP $FROM/usr/local/emacs/lisp/keypad.el  $TO/emacs/lisp/keypad.el
$CP $FROM/usr/local/emacs/lisp/keypad.elc  $TO/emacs/lisp/keypad.elc
$CP $FROM/usr/local/emacs/lisp/ledit.el  $TO/emacs/lisp/ledit.el
$CP $FROM/usr/local/emacs/lisp/life.el  $TO/emacs/lisp/life.el
$CP $FROM/usr/local/emacs/lisp/life.elc  $TO/emacs/lisp/life.elc
$CP $FROM/usr/local/emacs/lisp/lisp-mode.el  $TO/emacs/lisp/lisp-mode.el
$CP $FROM/usr/local/emacs/lisp/lisp-mode.elc  $TO/emacs/lisp/lisp-mode.elc
$CP $FROM/usr/local/emacs/lisp/lisp.el  $TO/emacs/lisp/lisp.el
$CP $FROM/usr/local/emacs/lisp/lisp.elc  $TO/emacs/lisp/lisp.elc
$CP $FROM/usr/local/emacs/lisp/loaddefs.el  $TO/emacs/lisp/loaddefs.el
$CP $FROM/usr/local/emacs/lisp/loadup.el  $TO/emacs/lisp/loadup.el
$CP $FROM/usr/local/emacs/lisp/lpr.el  $TO/emacs/lisp/lpr.el
$CP $FROM/usr/local/emacs/lisp/lpr.elc  $TO/emacs/lisp/lpr.elc
$CP $FROM/usr/local/emacs/lisp/macros.el  $TO/emacs/lisp/macros.el
$CP $FROM/usr/local/emacs/lisp/macros.elc  $TO/emacs/lisp/macros.elc
$CP $FROM/usr/local/emacs/lisp/mail-utils.el  $TO/emacs/lisp/mail-utils.el
$CP $FROM/usr/local/emacs/lisp/mail-utils.elc  $TO/emacs/lisp/mail-utils.elc
$CP $FROM/usr/local/emacs/lisp/mailalias.el  $TO/emacs/lisp/mailalias.el
$CP $FROM/usr/local/emacs/lisp/mailalias.elc  $TO/emacs/lisp/mailalias.elc
$CP $FROM/usr/local/emacs/lisp/mailpost.el  $TO/emacs/lisp/mailpost.el
$CP $FROM/usr/local/emacs/lisp/makesum.el  $TO/emacs/lisp/makesum.el
$CP $FROM/usr/local/emacs/lisp/makesum.elc  $TO/emacs/lisp/makesum.elc
$CP $FROM/usr/local/emacs/lisp/man.el  $TO/emacs/lisp/man.el
$CP $FROM/usr/local/emacs/lisp/man.elc  $TO/emacs/lisp/man.elc
$CP $FROM/usr/local/emacs/lisp/medit.el  $TO/emacs/lisp/medit.el
$CP $FROM/usr/local/emacs/lisp/medit.elc  $TO/emacs/lisp/medit.elc
$CP $FROM/usr/local/emacs/lisp/meese.el  $TO/emacs/lisp/meese.el
$CP $FROM/usr/local/emacs/lisp/mh-e.el  $TO/emacs/lisp/mh-e.el
$CP $FROM/usr/local/emacs/lisp/mh-e.elc  $TO/emacs/lisp/mh-e.elc
$CP $FROM/usr/local/emacs/lisp/mim-mode.el  $TO/emacs/lisp/mim-mode.el
$CP $FROM/usr/local/emacs/lisp/mim-mode.elc  $TO/emacs/lisp/mim-mode.elc
$CP $FROM/usr/local/emacs/lisp/mim-syntax.el  $TO/emacs/lisp/mim-syntax.el
$CP $FROM/usr/local/emacs/lisp/mim-syntax.elc  $TO/emacs/lisp/mim-syntax.elc
$CP $FROM/usr/local/emacs/lisp/mlconvert.el  $TO/emacs/lisp/mlconvert.el
$CP $FROM/usr/local/emacs/lisp/mlconvert.elc  $TO/emacs/lisp/mlconvert.elc
$CP $FROM/usr/local/emacs/lisp/mlsupport.el  $TO/emacs/lisp/mlsupport.el
$CP $FROM/usr/local/emacs/lisp/mlsupport.elc  $TO/emacs/lisp/mlsupport.elc
$CP $FROM/usr/local/emacs/lisp/modula2.el  $TO/emacs/lisp/modula2.el
$CP $FROM/usr/local/emacs/lisp/modula2.elc  $TO/emacs/lisp/modula2.elc
$CP $FROM/usr/local/emacs/lisp/novice.el  $TO/emacs/lisp/novice.el
$CP $FROM/usr/local/emacs/lisp/nroff-mode.el  $TO/emacs/lisp/nroff-mode.el
$CP $FROM/usr/local/emacs/lisp/nroff-mode.elc  $TO/emacs/lisp/nroff-mode.elc
$CP $FROM/usr/local/emacs/lisp/options.el  $TO/emacs/lisp/options.el
$CP $FROM/usr/local/emacs/lisp/options.elc  $TO/emacs/lisp/options.elc
$CP $FROM/usr/local/emacs/lisp/outline.el  $TO/emacs/lisp/outline.el
$CP $FROM/usr/local/emacs/lisp/outline.elc  $TO/emacs/lisp/outline.elc
$CP $FROM/usr/local/emacs/lisp/page.el  $TO/emacs/lisp/page.el
$CP $FROM/usr/local/emacs/lisp/page.elc  $TO/emacs/lisp/page.elc
$CP $FROM/usr/local/emacs/lisp/paragraphs.el  $TO/emacs/lisp/paragraphs.el
$CP $FROM/usr/local/emacs/lisp/paragraphs.elc  $TO/emacs/lisp/paragraphs.elc
$CP $FROM/usr/local/emacs/lisp/paths.el  $TO/emacs/lisp/paths.el
$CP $FROM/usr/local/emacs/lisp/picture.el  $TO/emacs/lisp/picture.el
$CP $FROM/usr/local/emacs/lisp/picture.elc  $TO/emacs/lisp/picture.elc
$CP $FROM/usr/local/emacs/lisp/prolog.el  $TO/emacs/lisp/prolog.el
$CP $FROM/usr/local/emacs/lisp/prolog.elc  $TO/emacs/lisp/prolog.elc
$CP $FROM/usr/local/emacs/lisp/rect.el  $TO/emacs/lisp/rect.el
$CP $FROM/usr/local/emacs/lisp/rect.elc  $TO/emacs/lisp/rect.elc
$CP $FROM/usr/local/emacs/lisp/register.el  $TO/emacs/lisp/register.el
$CP $FROM/usr/local/emacs/lisp/register.elc  $TO/emacs/lisp/register.elc
$CP $FROM/usr/local/emacs/lisp/replace.el  $TO/emacs/lisp/replace.el
$CP $FROM/usr/local/emacs/lisp/replace.elc  $TO/emacs/lisp/replace.elc
$CP $FROM/usr/local/emacs/lisp/rfc822.el  $TO/emacs/lisp/rfc822.el
$CP $FROM/usr/local/emacs/lisp/rfc822.elc  $TO/emacs/lisp/rfc822.elc
$CP $FROM/usr/local/emacs/lisp/rmail.el  $TO/emacs/lisp/rmail.el
$CP $FROM/usr/local/emacs/lisp/rmail.elc  $TO/emacs/lisp/rmail.elc
$CP $FROM/usr/local/emacs/lisp/rmailedit.el  $TO/emacs/lisp/rmailedit.el
$CP $FROM/usr/local/emacs/lisp/rmailedit.elc  $TO/emacs/lisp/rmailedit.elc
$CP $FROM/usr/local/emacs/lisp/rmailkwd.el  $TO/emacs/lisp/rmailkwd.el
$CP $FROM/usr/local/emacs/lisp/rmailkwd.elc  $TO/emacs/lisp/rmailkwd.elc
$CP $FROM/usr/local/emacs/lisp/rmailmsc.el  $TO/emacs/lisp/rmailmsc.el
$CP $FROM/usr/local/emacs/lisp/rmailmsc.elc  $TO/emacs/lisp/rmailmsc.elc
$CP $FROM/usr/local/emacs/lisp/rmailout.el  $TO/emacs/lisp/rmailout.el
$CP $FROM/usr/local/emacs/lisp/rmailout.elc  $TO/emacs/lisp/rmailout.elc
$CP $FROM/usr/local/emacs/lisp/rmailsum.el  $TO/emacs/lisp/rmailsum.el
$CP $FROM/usr/local/emacs/lisp/rmailsum.elc  $TO/emacs/lisp/rmailsum.elc
$CP $FROM/usr/local/emacs/lisp/rnews.el  $TO/emacs/lisp/rnews.el
$CP $FROM/usr/local/emacs/lisp/rnews.elc  $TO/emacs/lisp/rnews.elc
$CP $FROM/usr/local/emacs/lisp/rnewspost.el  $TO/emacs/lisp/rnewspost.el
$CP $FROM/usr/local/emacs/lisp/rnewspost.elc  $TO/emacs/lisp/rnewspost.elc
$CP $FROM/usr/local/emacs/lisp/saveconf.el  $TO/emacs/lisp/saveconf.el
$CP $FROM/usr/local/emacs/lisp/scheme.el  $TO/emacs/lisp/scheme.el
$CP $FROM/usr/local/emacs/lisp/scheme.elc  $TO/emacs/lisp/scheme.elc
$CP $FROM/usr/local/emacs/lisp/scribe.el  $TO/emacs/lisp/scribe.el
$CP $FROM/usr/local/emacs/lisp/scribe.elc  $TO/emacs/lisp/scribe.elc
$CP $FROM/usr/local/emacs/lisp/sendmail.el  $TO/emacs/lisp/sendmail.el
$CP $FROM/usr/local/emacs/lisp/sendmail.elc  $TO/emacs/lisp/sendmail.elc
$CP $FROM/usr/local/emacs/lisp/server.el  $TO/emacs/lisp/server.el
$CP $FROM/usr/local/emacs/lisp/server.elc  $TO/emacs/lisp/server.elc
$CP $FROM/usr/local/emacs/lisp/shell.el  $TO/emacs/lisp/shell.el
$CP $FROM/usr/local/emacs/lisp/shell.elc  $TO/emacs/lisp/shell.elc
$CP $FROM/usr/local/emacs/lisp/simple.el  $TO/emacs/lisp/simple.el
$CP $FROM/usr/local/emacs/lisp/simple.elc  $TO/emacs/lisp/simple.elc
$CP $FROM/usr/local/emacs/lisp/simula.defns  $TO/emacs/lisp/simula.defns
$CP $FROM/usr/local/emacs/lisp/simula.el  $TO/emacs/lisp/simula.el
$CP $FROM/usr/local/emacs/lisp/simula.elc  $TO/emacs/lisp/simula.elc
$CP $FROM/usr/local/emacs/lisp/sort.el  $TO/emacs/lisp/sort.el
$CP $FROM/usr/local/emacs/lisp/sort.elc  $TO/emacs/lisp/sort.elc
$CP $FROM/usr/local/emacs/lisp/spell.el  $TO/emacs/lisp/spell.el
$CP $FROM/usr/local/emacs/lisp/spell.elc  $TO/emacs/lisp/spell.elc
$CP $FROM/usr/local/emacs/lisp/spook.el  $TO/emacs/lisp/spook.el
$CP $FROM/usr/local/emacs/lisp/startup.el  $TO/emacs/lisp/startup.el
$CP $FROM/usr/local/emacs/lisp/startup.elc  $TO/emacs/lisp/startup.elc
$CP $FROM/usr/local/emacs/lisp/studly.el  $TO/emacs/lisp/studly.el
$CP $FROM/usr/local/emacs/lisp/studly.elc  $TO/emacs/lisp/studly.elc
$CP $FROM/usr/local/emacs/lisp/subr.el  $TO/emacs/lisp/subr.el
$CP $FROM/usr/local/emacs/lisp/subr.elc  $TO/emacs/lisp/subr.elc
$CP $FROM/usr/local/emacs/lisp/sun-cursors.el  $TO/emacs/lisp/sun-cursors.el
$CP $FROM/usr/local/emacs/lisp/sun-fns.el  $TO/emacs/lisp/sun-fns.el
$CP $FROM/usr/local/emacs/lisp/sun-fns.elc  $TO/emacs/lisp/sun-fns.elc
$CP $FROM/usr/local/emacs/lisp/sun-keys.el  $TO/emacs/lisp/sun-keys.el
$CP $FROM/usr/local/emacs/lisp/sun-mouse.el  $TO/emacs/lisp/sun-mouse.el
$CP $FROM/usr/local/emacs/lisp/sun-mouse.elc  $TO/emacs/lisp/sun-mouse.elc
$CP $FROM/usr/local/emacs/lisp/sup-mouse.el  $TO/emacs/lisp/sup-mouse.el
$CP $FROM/usr/local/emacs/lisp/sup-mouse.elc  $TO/emacs/lisp/sup-mouse.elc
$CP $FROM/usr/local/emacs/lisp/tabify.el  $TO/emacs/lisp/tabify.el
$CP $FROM/usr/local/emacs/lisp/tabify.elc  $TO/emacs/lisp/tabify.elc
$CP $FROM/usr/local/emacs/lisp/tags.el  $TO/emacs/lisp/tags.el
$CP $FROM/usr/local/emacs/lisp/tags.elc  $TO/emacs/lisp/tags.elc
$CP $FROM/usr/local/emacs/lisp/telnet.el  $TO/emacs/lisp/telnet.el
$CP $FROM/usr/local/emacs/lisp/telnet.elc  $TO/emacs/lisp/telnet.elc
if test ! -d $TO/emacs/lisp/term ; then mkdir -p $TO/emacs/lisp/term; fi
$CP $FROM/usr/local/emacs/lisp/term/COPYING  $TO/emacs/lisp/term/COPYING
$CP $FROM/usr/local/emacs/lisp/term/apollo.el  $TO/emacs/lisp/term/apollo.el
$CP $FROM/usr/local/emacs/lisp/term/at386.el  $TO/emacs/lisp/term/at386.el
$CP $FROM/usr/local/emacs/lisp/term/bbn.el  $TO/emacs/lisp/term/bbn.el
$CP $FROM/usr/local/emacs/lisp/term/bg.el  $TO/emacs/lisp/term/bg.el
$CP $FROM/usr/local/emacs/lisp/term/bgnv.el  $TO/emacs/lisp/term/bgnv.el
$CP $FROM/usr/local/emacs/lisp/term/bgrv.el  $TO/emacs/lisp/term/bgrv.el
$CP $FROM/usr/local/emacs/lisp/term/bobcat.el  $TO/emacs/lisp/term/bobcat.el
$CP $FROM/usr/local/emacs/lisp/term/s4.el  $TO/emacs/lisp/term/s4.el
$CP $FROM/usr/local/emacs/lisp/term/sun.el  $TO/emacs/lisp/term/sun.el
$CP $FROM/usr/local/emacs/lisp/term/supdup.el  $TO/emacs/lisp/term/supdup.el
$CP $FROM/usr/local/emacs/lisp/term/unixpc.el  $TO/emacs/lisp/term/unixpc.el
$CP $FROM/usr/local/emacs/lisp/term/vt100.el  $TO/emacs/lisp/term/vt100.el
$CP $FROM/usr/local/emacs/lisp/term/vt101.el  $TO/emacs/lisp/term/vt101.el
$CP $FROM/usr/local/emacs/lisp/term/vt102.el  $TO/emacs/lisp/term/vt102.el
$CP $FROM/usr/local/emacs/lisp/term/vt125.el  $TO/emacs/lisp/term/vt125.el
$CP $FROM/usr/local/emacs/lisp/term/vt131.el  $TO/emacs/lisp/term/vt131.el
$CP $FROM/usr/local/emacs/lisp/term/vt200.el  $TO/emacs/lisp/term/vt200.el
$CP $FROM/usr/local/emacs/lisp/term/vt220.el  $TO/emacs/lisp/term/vt220.el
$CP $FROM/usr/local/emacs/lisp/term/vt240.el  $TO/emacs/lisp/term/vt240.el
$CP $FROM/usr/local/emacs/lisp/term/vt300.el  $TO/emacs/lisp/term/vt300.el
$CP $FROM/usr/local/emacs/lisp/term/x-win.el  $TO/emacs/lisp/term/x-win.el
$CP $FROM/usr/local/emacs/lisp/term/xterm.el  $TO/emacs/lisp/term/xterm.el
$CP $FROM/usr/local/emacs/lisp/terminal.el  $TO/emacs/lisp/terminal.el
$CP $FROM/usr/local/emacs/lisp/terminal.elc  $TO/emacs/lisp/terminal.elc
$CP $FROM/usr/local/emacs/lisp/tex-mode.el  $TO/emacs/lisp/tex-mode.el
$CP $FROM/usr/local/emacs/lisp/tex-mode.elc  $TO/emacs/lisp/tex-mode.elc
$CP $FROM/usr/local/emacs/lisp/tex-start.el  $TO/emacs/lisp/tex-start.el
$CP $FROM/usr/local/emacs/lisp/texinfmt.el  $TO/emacs/lisp/texinfmt.el
$CP $FROM/usr/local/emacs/lisp/texinfmt.elc  $TO/emacs/lisp/texinfmt.elc
$CP $FROM/usr/local/emacs/lisp/texinfo.el  $TO/emacs/lisp/texinfo.el
$CP $FROM/usr/local/emacs/lisp/texinfo.elc  $TO/emacs/lisp/texinfo.elc
$CP $FROM/usr/local/emacs/lisp/text-mode.el  $TO/emacs/lisp/text-mode.el
$CP $FROM/usr/local/emacs/lisp/text-mode.elc  $TO/emacs/lisp/text-mode.elc
$CP $FROM/usr/local/emacs/lisp/time.el  $TO/emacs/lisp/time.el
$CP $FROM/usr/local/emacs/lisp/time.elc  $TO/emacs/lisp/time.elc
$CP $FROM/usr/local/emacs/lisp/uncompress.el  $TO/emacs/lisp/uncompress.el
$CP $FROM/usr/local/emacs/lisp/underline.el  $TO/emacs/lisp/underline.el
$CP $FROM/usr/local/emacs/lisp/underline.elc  $TO/emacs/lisp/underline.elc
$CP $FROM/usr/local/emacs/lisp/undigest.el  $TO/emacs/lisp/undigest.el
$CP $FROM/usr/local/emacs/lisp/undigest.elc  $TO/emacs/lisp/undigest.elc
$CP $FROM/usr/local/emacs/lisp/unused.el  $TO/emacs/lisp/unused.el
$CP $FROM/usr/local/emacs/lisp/userlock.el  $TO/emacs/lisp/userlock.el
$CP $FROM/usr/local/emacs/lisp/userlock.elc  $TO/emacs/lisp/userlock.elc
$CP $FROM/usr/local/emacs/lisp/version.el  $TO/emacs/lisp/version.el
$CP $FROM/usr/local/emacs/lisp/vi.el  $TO/emacs/lisp/vi.el
$CP $FROM/usr/local/emacs/lisp/vi.elc  $TO/emacs/lisp/vi.elc
$CP $FROM/usr/local/emacs/lisp/view.el  $TO/emacs/lisp/view.el
$CP $FROM/usr/local/emacs/lisp/view.elc  $TO/emacs/lisp/view.elc
$CP $FROM/usr/local/emacs/lisp/vip.el  $TO/emacs/lisp/vip.el
$CP $FROM/usr/local/emacs/lisp/vip.elc  $TO/emacs/lisp/vip.elc
$CP $FROM/usr/local/emacs/lisp/vms-patch.el  $TO/emacs/lisp/vms-patch.el
$CP $FROM/usr/local/emacs/lisp/vms-patch.elc  $TO/emacs/lisp/vms-patch.elc
$CP $FROM/usr/local/emacs/lisp/vmsproc.el  $TO/emacs/lisp/vmsproc.el
$CP $FROM/usr/local/emacs/lisp/vmsproc.elc  $TO/emacs/lisp/vmsproc.elc
$CP $FROM/usr/local/emacs/lisp/window.el  $TO/emacs/lisp/window.el
$CP $FROM/usr/local/emacs/lisp/window.elc  $TO/emacs/lisp/window.elc
$CP $FROM/usr/local/emacs/lisp/x-menu.el  $TO/emacs/lisp/x-menu.el
$CP $FROM/usr/local/emacs/lisp/x-menu.elc  $TO/emacs/lisp/x-menu.elc
$CP $FROM/usr/local/emacs/lisp/x-mouse.el  $TO/emacs/lisp/x-mouse.el
$CP $FROM/usr/local/emacs/lisp/x-mouse.elc  $TO/emacs/lisp/x-mouse.elc
$CP $FROM/usr/local/emacs/lisp/xscheme.el  $TO/emacs/lisp/xscheme.el
$CP $FROM/usr/local/emacs/lisp/xscheme.elc  $TO/emacs/lisp/xscheme.elc
$CP $FROM/usr/local/emacs/lisp/yow.el  $TO/emacs/lisp/yow.el
$CP $FROM/usr/local/emacs/lisp/yow.elc  $TO/emacs/lisp/yow.elc
if test ! -d $TO/etc ; then mkdir -p $TO/etc; fi
$CP $FROM/usr/local/etc/mslaved  $TO/etc/mslaved
$CP $FROM/usr/local/etc/mslavedc  $TO/etc/mslavedc
if test ! -d $TO/games ; then mkdir -p $TO/games; fi
$CP $FROM/usr/local/games/bincheckr  $TO/games/bincheckr
$CP $FROM/usr/local/games/checkgame  $TO/games/checkgame
$CP $FROM/usr/local/games/gnuan  $TO/games/gnuan
$CP $FROM/usr/local/games/gnuchess  $TO/games/gnuchess
$CP $FROM/usr/local/games/gnuchessc  $TO/games/gnuchessc
$CP $FROM/usr/local/games/gnuchessn  $TO/games/gnuchessn
$CP $FROM/usr/local/games/gnuchessr  $TO/games/gnuchessr
$CP $FROM/usr/local/games/gnuchessx  $TO/games/gnuchessx
$CP $FROM/usr/local/games/gnugo  $TO/games/gnugo
$CP $FROM/usr/local/games/postprint  $TO/games/postprint
if test ! -d $TO/include ; then mkdir -p $TO/include; fi
$CP $FROM/usr/local/include/__math.h  $TO/include/__math.h
$CP $FROM/usr/local/include/a.out.h  $TO/include/a.out.h
$CP $FROM/usr/local/include/alloca.h  $TO/include/alloca.h
if test ! -d $TO/include/arpa ; then mkdir -p $TO/include/arpa; fi
$CP $FROM/usr/local/include/arpa/ftp.h  $TO/include/arpa/ftp.h
$CP $FROM/usr/local/include/arpa/inet.h  $TO/include/arpa/inet.h
$CP $FROM/usr/local/include/arpa/nameser.h  $TO/include/arpa/nameser.h
$CP $FROM/usr/local/include/arpa/telnet.h  $TO/include/arpa/telnet.h
$CP $FROM/usr/local/include/arpa/tftp.h  $TO/include/arpa/tftp.h
$CP $FROM/usr/local/include/assert.h  $TO/include/assert.h
$CP $FROM/usr/local/include/bfd.h  $TO/include/bfd.h
$CP $FROM/usr/local/include/ctype.h  $TO/include/ctype.h
$CP $FROM/usr/local/include/dirent.h  $TO/include/dirent.h
$CP $FROM/usr/local/include/endian.h  $TO/include/endian.h
$CP $FROM/usr/local/include/errno.h  $TO/include/errno.h
$CP $FROM/usr/local/include/errnos.h  $TO/include/errnos.h
$CP $FROM/usr/local/include/fcntl.h  $TO/include/fcntl.h
$CP $FROM/usr/local/include/fcntlbits.h  $TO/include/fcntlbits.h
$CP $FROM/usr/local/include/features.h  $TO/include/features.h
$CP $FROM/usr/local/include/filebits.h  $TO/include/filebits.h
$CP $FROM/usr/local/include/fnmatch.h  $TO/include/fnmatch.h
$CP $FROM/usr/local/include/ftw.h  $TO/include/ftw.h
$CP $FROM/usr/local/include/gdbm.h  $TO/include/gdbm.h
$CP $FROM/usr/local/include/getopt.h  $TO/include/getopt.h
$CP $FROM/usr/local/include/glob.h  $TO/include/glob.h
if test ! -d $TO/include/gnu ; then mkdir -p $TO/include/gnu; fi
$CP $FROM/usr/local/include/gnu/signal.h  $TO/include/gnu/signal.h
$CP $FROM/usr/local/include/gnu/types.h  $TO/include/gnu/types.h
$CP $FROM/usr/local/include/gnu/wait.h  $TO/include/gnu/wait.h
$CP $FROM/usr/local/include/grp.h  $TO/include/grp.h
$CP $FROM/usr/local/include/huge_val.h  $TO/include/huge_val.h
$CP $FROM/usr/local/include/inet-cvt.h  $TO/include/inet-cvt.h
$CP $FROM/usr/local/include/ioctls.h  $TO/include/ioctls.h
$CP $FROM/usr/local/include/jmp_buf.h  $TO/include/jmp_buf.h
$CP $FROM/usr/local/include/limits.h  $TO/include/limits.h
$CP $FROM/usr/local/include/local_lim.h  $TO/include/local_lim.h
$CP $FROM/usr/local/include/locale.h  $TO/include/locale.h
$CP $FROM/usr/local/include/localeinfo.h  $TO/include/localeinfo.h
$CP $FROM/usr/local/include/malloc.h  $TO/include/malloc.h
$CP $FROM/usr/local/include/math.h  $TO/include/math.h
$CP $FROM/usr/local/include/memory.h  $TO/include/memory.h
$CP $FROM/usr/local/include/nan.h  $TO/include/nan.h
$CP $FROM/usr/local/include/netdb.h  $TO/include/netdb.h
if test ! -d $TO/include/netinet ; then mkdir -p $TO/include/netinet; fi
$CP $FROM/usr/local/include/netinet/in.h  $TO/include/netinet/in.h
$CP $FROM/usr/local/include/nlist.h  $TO/include/nlist.h
$CP $FROM/usr/local/include/obstack.h  $TO/include/obstack.h
$CP $FROM/usr/local/include/paths.h  $TO/include/paths.h
$CP $FROM/usr/local/include/posix1_lim.h  $TO/include/posix1_lim.h
$CP $FROM/usr/local/include/posix2_lim.h  $TO/include/posix2_lim.h
$CP $FROM/usr/local/include/posix_opt.h  $TO/include/posix_opt.h
$CP $FROM/usr/local/include/printf.h  $TO/include/printf.h
if test ! -d $TO/include/protocols; then mkdir -p $TO/include/protocols; fi
$CP $FROM/usr/local/include/protocols/routed.h  $TO/include/protocols/routed.h
$CP $FROM/usr/local/include/protocols/rwhod.h  $TO/include/protocols/rwhod.h
$CP $FROM/usr/local/include/protocols/talkd.h  $TO/include/protocols/talkd.h
$CP $FROM/usr/local/include/protocols/timed.h  $TO/include/protocols/timed.h
$CP $FROM/usr/local/include/pwd.h  $TO/include/pwd.h
if test ! -d $TO/include/readline; then mkdir -p $TO/include/readline; fi
$CP $FROM/usr/local/include/readline/chardefs.h  $TO/include/readline/chardefs.h
$CP $FROM/usr/local/include/readline/keymaps.h  $TO/include/readline/keymaps.h
$CP $FROM/usr/local/include/readline/readline.h  $TO/include/readline/readline.h
$CP $FROM/usr/local/include/resolv.h  $TO/include/resolv.h
$CP $FROM/usr/local/include/setjmp.h  $TO/include/setjmp.h
$CP $FROM/usr/local/include/sgtty.h  $TO/include/sgtty.h
$CP $FROM/usr/local/include/sigcontext.h  $TO/include/sigcontext.h
$CP $FROM/usr/local/include/signal.h  $TO/include/signal.h
$CP $FROM/usr/local/include/signum.h  $TO/include/signum.h
$CP $FROM/usr/local/include/stab.def  $TO/include/stab.def
$CP $FROM/usr/local/include/stab.h  $TO/include/stab.h
$CP $FROM/usr/local/include/statbuf.h  $TO/include/statbuf.h
$CP $FROM/usr/local/include/stdarg.h  $TO/include/stdarg.h
$CP $FROM/usr/local/include/stddef.h  $TO/include/stddef.h
$CP $FROM/usr/local/include/stdio.h  $TO/include/stdio.h
$CP $FROM/usr/local/include/stdio_lim.h  $TO/include/stdio_lim.h
$CP $FROM/usr/local/include/stdlib.h  $TO/include/stdlib.h
$CP $FROM/usr/local/include/string.h  $TO/include/string.h
$CP $FROM/usr/local/include/strings.h  $TO/include/strings.h
if test ! -d $TO/include/sys ; then mkdir -p $TO/include/sys; fi
$CP $FROM/usr/local/include/sys/cdefs.h  $TO/include/sys/cdefs.h
$CP $FROM/usr/local/include/sys/dir.h  $TO/include/sys/dir.h
$CP $FROM/usr/local/include/sys/errno.h  $TO/include/sys/errno.h
$CP $FROM/usr/local/include/sys/file.h  $TO/include/sys/file.h
$CP $FROM/usr/local/include/sys/ioctl.h  $TO/include/sys/ioctl.h
$CP $FROM/usr/local/include/sys/ptrace.h  $TO/include/sys/ptrace.h
$CP $FROM/usr/local/include/sys/resource.h  $TO/include/sys/resource.h
$CP $FROM/usr/local/include/sys/signal.h  $TO/include/sys/signal.h
$CP $FROM/usr/local/include/sys/socket.h  $TO/include/sys/socket.h
$CP $FROM/usr/local/include/sys/stat.h  $TO/include/sys/stat.h
$CP $FROM/usr/local/include/sys/syslog.h  $TO/include/sys/syslog.h
$CP $FROM/usr/local/include/sys/termios.h  $TO/include/sys/termios.h
$CP $FROM/usr/local/include/sys/times.h  $TO/include/sys/times.h
$CP $FROM/usr/local/include/sys/ttydefaults.h  $TO/include/sys/ttydefaults.h
$CP $FROM/usr/local/include/sys/types.h  $TO/include/sys/types.h
$CP $FROM/usr/local/include/sys/uio.h  $TO/include/sys/uio.h
$CP $FROM/usr/local/include/sys/un.h  $TO/include/sys/un.h
$CP $FROM/usr/local/include/sys/utsname.h  $TO/include/sys/utsname.h
$CP $FROM/usr/local/include/sys/vlimit.h  $TO/include/sys/vlimit.h
$CP $FROM/usr/local/include/sys/vtimes.h  $TO/include/sys/vtimes.h
$CP $FROM/usr/local/include/sys/wait.h  $TO/include/sys/wait.h
$CP $FROM/usr/local/include/syscall.h  $TO/include/syscall.h
$CP $FROM/usr/local/include/tar.h  $TO/include/tar.h
$CP $FROM/usr/local/include/termcap.h  $TO/include/termcap.h
$CP $FROM/usr/local/include/termios.h  $TO/include/termios.h
$CP $FROM/usr/local/include/ttyent.h  $TO/include/ttyent.h
$CP $FROM/usr/local/include/unistd.h  $TO/include/unistd.h
$CP $FROM/usr/local/include/utime.h  $TO/include/utime.h
$CP $FROM/usr/local/include/va-alpha.h  $TO/include/va-alpha.h
$CP $FROM/usr/local/include/va-i860.h  $TO/include/va-i860.h
$CP $FROM/usr/local/include/va-i960.h  $TO/include/va-i960.h
$CP $FROM/usr/local/include/va-m88k.h  $TO/include/va-m88k.h
$CP $FROM/usr/local/include/va-mips.h  $TO/include/va-mips.h
$CP $FROM/usr/local/include/va-pa.h  $TO/include/va-pa.h
$CP $FROM/usr/local/include/va-pyr.h  $TO/include/va-pyr.h
$CP $FROM/usr/local/include/va-sparc.h  $TO/include/va-sparc.h
$CP $FROM/usr/local/include/va-spur.h  $TO/include/va-spur.h
$CP $FROM/usr/local/include/wordexp.h  $TO/include/wordexp.h
if test ! -d $TO/info ; then mkdir -p $TO/info; fi
$CP $FROM/usr/local/info/autoconf.info  $TO/info/autoconf.info
$CP $FROM/usr/local/info/bison.info  $TO/info/bison.info
$CP $FROM/usr/local/info/bison.info-1  $TO/info/bison.info-1
$CP $FROM/usr/local/info/bison.info-2  $TO/info/bison.info-2
$CP $FROM/usr/local/info/bison.info-3  $TO/info/bison.info-3
$CP $FROM/usr/local/info/bison.info-4  $TO/info/bison.info-4
$CP $FROM/usr/local/info/diff.info  $TO/info/diff.info
$CP $FROM/usr/local/info/diff.info-1  $TO/info/diff.info-1
$CP $FROM/usr/local/info/diff.info-2  $TO/info/diff.info-2
$CP $FROM/usr/local/info/diff.info-3  $TO/info/diff.info-3
$CP $FROM/usr/local/info/gptx.info  $TO/info/gptx.info
$CP $FROM/usr/local/info/graphics.info  $TO/info/graphics.info
$CP $FROM/usr/local/info/hello.info  $TO/info/hello.info
$CP $FROM/usr/local/info/indent.info  $TO/info/indent.info
$CP $FROM/usr/local/info/recode.info  $TO/info/recode.info
$CP $FROM/usr/local/info/standards.info  $TO/info/standards.info
$CP $FROM/usr/local/info/termcap.info  $TO/info/termcap.info
$CP $FROM/usr/local/info/termcap.info-1  $TO/info/termcap.info-1
$CP $FROM/usr/local/info/termcap.info-2  $TO/info/termcap.info-2
$CP $FROM/usr/local/info/termcap.info-3  $TO/info/termcap.info-3
$CP $FROM/usr/local/info/termcap.info-4  $TO/info/termcap.info-4
$CP $FROM/usr/local/info/time.info  $TO/info/time.info
$CP $FROM/usr/local/info/uucp.info  $TO/info/uucp.info
$CP $FROM/usr/local/info/uucp.info-1  $TO/info/uucp.info-1
$CP $FROM/usr/local/info/uucp.info-2  $TO/info/uucp.info-2
$CP $FROM/usr/local/info/uucp.info-3  $TO/info/uucp.info-3
$CP $FROM/usr/local/info/uucp.info-4  $TO/info/uucp.info-4
$CP $FROM/usr/local/info/wdiff.info  $TO/info/wdiff.info
if test ! -d $TO/lib ; then mkdir -p $TO/lib; fi
$CP $FROM/usr/local/lib/acgeneral.m4  $TO/lib/acgeneral.m4
$CP $FROM/usr/local/lib/acspecific.m4  $TO/lib/acspecific.m4
$CP $FROM/usr/local/lib/bison.hairy  $TO/lib/bison.hairy
$CP $FROM/usr/local/lib/bison.simple  $TO/lib/bison.simple
$CP $FROM/usr/local/lib/crt0.o  $TO/lib/crt0.o
if test ! -d $TO/lib/emacs ; then mkdir -p $TO/lib/emacs; fi
if test ! -d $TO/lib/emacs/info ; then mkdir -p $TO/lib/emacs/info; fi
$CP $FROM/usr/local/lib/emacs/info/m4  $TO/lib/emacs/info/m4
$CP $FROM/usr/local/lib/emacs/info/m4.info-1  $TO/lib/emacs/info/m4.info-1
$CP $FROM/usr/local/lib/emacs/info/m4.info-2  $TO/lib/emacs/info/m4.info-2
$CP $FROM/usr/local/lib/flex.skel  $TO/lib/flex.skel
if test ! -d $TO/lib/gcc-lib ; then mkdir -p $TO/lib/gcc-lib; fi
if test ! -d $TO/lib/sparc-sun-sunos4.1 ; then mkdir -p $TO/lib/gcc-lib/sparc-sun-sunos4.1; fi
if test ! -d $TO/lib/sparc-sun-sunos4.1/2.3.1 ; then mkdir -p $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1; fi
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/SYSCALLS.c.X  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/SYSCALLS.c.X
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cc1  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cc1
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cc1obj  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cc1obj
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cc1plus  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cc1plus
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cpp  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/cpp
if test ! -d $TO/lib/sparc-sun-sunos4.1/2.3.1/include ; then mkdir -p $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include; fi
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/float.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/float.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/limits.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/limits.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/proto.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/proto.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/stdarg.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/stdarg.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/stddef.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/stddef.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/syslimits.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/syslimits.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-alpha.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-alpha.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-i860.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-i860.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-i960.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-i960.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-m88k.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-m88k.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-mips.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-mips.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-pa.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-pa.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-pyr.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-pyr.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-sparc.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-sparc.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-spur.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/va-spur.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/varargs.h  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/include/varargs.h
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/ld  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/ld
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/libgcc.a  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/libgcc.a
$CP $FROM/usr/local/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/specs  $TO/lib/gcc-lib/sparc-sun-sunos4.1/2.3.1/specs
if test ! -d $TO/lib/ghostscript ; then mkdir -p $TO/lib/ghostscript ; fi
$CP $FROM/usr/local/lib/ghostscript/Fontmap  $TO/lib/ghostscript/Fontmap
$CP $FROM/usr/local/lib/ghostscript/README  $TO/lib/ghostscript/README
$CP $FROM/usr/local/lib/ghostscript/bdftops.ps  $TO/lib/ghostscript/bdftops.ps
$CP $FROM/usr/local/lib/ghostscript/decrypt.ps  $TO/lib/ghostscript/decrypt.ps
if test ! -d $TO/lib/ghostscript/doc; then mkdir -p $TO/lib/ghostscript/doc; fi
$CP $FROM/usr/local/lib/ghostscript/doc/NEWS  $TO/lib/ghostscript/doc/NEWS
$CP $FROM/usr/local/lib/ghostscript/doc/drivers.doc  $TO/lib/ghostscript/doc/drivers.doc
$CP $FROM/usr/local/lib/ghostscript/doc/fonts.doc  $TO/lib/ghostscript/doc/fonts.doc
$CP $FROM/usr/local/lib/ghostscript/doc/hershey.doc  $TO/lib/ghostscript/doc/hershey.doc
$CP $FROM/usr/local/lib/ghostscript/doc/history.doc  $TO/lib/ghostscript/doc/history.doc
$CP $FROM/usr/local/lib/ghostscript/doc/humor.doc  $TO/lib/ghostscript/doc/humor.doc
$CP $FROM/usr/local/lib/ghostscript/doc/language.doc  $TO/lib/ghostscript/doc/language.doc
$CP $FROM/usr/local/lib/ghostscript/doc/lib.doc  $TO/lib/ghostscript/doc/lib.doc
$CP $FROM/usr/local/lib/ghostscript/doc/make.doc  $TO/lib/ghostscript/doc/make.doc
$CP $FROM/usr/local/lib/ghostscript/doc/psfiles.doc  $TO/lib/ghostscript/doc/psfiles.doc
$CP $FROM/usr/local/lib/ghostscript/doc/readme.doc  $TO/lib/ghostscript/doc/readme.doc
$CP $FROM/usr/local/lib/ghostscript/doc/use.doc  $TO/lib/ghostscript/doc/use.doc
if test ! -d $TO/lib/ghostscript/examples; then mkdir -p $TO/lib/ghostscript/examples; fi
$CP $FROM/usr/local/lib/ghostscript/examples/cheq.ps  $TO/lib/ghostscript/examples/cheq.ps
$CP $FROM/usr/local/lib/ghostscript/examples/chess.ps  $TO/lib/ghostscript/examples/chess.ps
$CP $FROM/usr/local/lib/ghostscript/examples/colorcir.ps  $TO/lib/ghostscript/examples/colorcir.ps
$CP $FROM/usr/local/lib/ghostscript/examples/escher.ps  $TO/lib/ghostscript/examples/escher.ps
$CP $FROM/usr/local/lib/ghostscript/examples/golfer.ps  $TO/lib/ghostscript/examples/golfer.ps
$CP $FROM/usr/local/lib/ghostscript/examples/snowflak.ps  $TO/lib/ghostscript/examples/snowflak.ps
$CP $FROM/usr/local/lib/ghostscript/examples/tiger.ps  $TO/lib/ghostscript/examples/tiger.ps
$CP $FROM/usr/local/lib/ghostscript/font2c.ps  $TO/lib/ghostscript/font2c.ps
$CP $FROM/usr/local/lib/ghostscript/gs_2asc.ps  $TO/lib/ghostscript/gs_2asc.ps
$CP $FROM/usr/local/lib/ghostscript/gs_dps1.ps  $TO/lib/ghostscript/gs_dps1.ps
$CP $FROM/usr/local/lib/ghostscript/gs_fonts.ps  $TO/lib/ghostscript/gs_fonts.ps
$CP $FROM/usr/local/lib/ghostscript/gs_init.ps  $TO/lib/ghostscript/gs_init.ps
$CP $FROM/usr/local/lib/ghostscript/gs_lev2.ps  $TO/lib/ghostscript/gs_lev2.ps
$CP $FROM/usr/local/lib/ghostscript/gs_statd.ps  $TO/lib/ghostscript/gs_statd.ps
$CP $FROM/usr/local/lib/ghostscript/gslp.ps  $TO/lib/ghostscript/gslp.ps
$CP $FROM/usr/local/lib/ghostscript/impath.ps  $TO/lib/ghostscript/impath.ps
$CP $FROM/usr/local/lib/ghostscript/landscap.ps  $TO/lib/ghostscript/landscap.ps
$CP $FROM/usr/local/lib/ghostscript/prfont.ps  $TO/lib/ghostscript/prfont.ps
$CP $FROM/usr/local/lib/ghostscript/pstoppm.ps  $TO/lib/ghostscript/pstoppm.ps
$CP $FROM/usr/local/lib/ghostscript/quit.ps  $TO/lib/ghostscript/quit.ps
$CP $FROM/usr/local/lib/ghostscript/sym__enc.ps  $TO/lib/ghostscript/sym__enc.ps
$CP $FROM/usr/local/lib/ghostscript/type1ops.ps  $TO/lib/ghostscript/type1ops.ps
$CP $FROM/usr/local/lib/ghostscript/uglyr.gsf  $TO/lib/ghostscript/uglyr.gsf
$CP $FROM/usr/local/lib/ghostscript/wrfont.ps  $TO/lib/ghostscript/wrfont.ps
$CP $FROM/usr/local/lib/gnuplot.gih  $TO/lib/gnuplot.gih
if test ! -d $TO/lib/ispell; then mkdir -p $TO/lib/ispell; fi
$CP $FROM/usr/local/lib/ispell/icombine  $TO/lib/ispell/icombine
$CP $FROM/usr/local/lib/ispell/isexp1.sed  $TO/lib/ispell/isexp1.sed
$CP $FROM/usr/local/lib/ispell/isexp2.sed  $TO/lib/ispell/isexp2.sed
$CP $FROM/usr/local/lib/ispell/isexp3.sed  $TO/lib/ispell/isexp3.sed
$CP $FROM/usr/local/lib/ispell/isexp4.sed  $TO/lib/ispell/isexp4.sed
$CP $FROM/usr/local/lib/ispell/ispell.hash  $TO/lib/ispell/ispell.hash
$CP $FROM/usr/local/lib/ld  $TO/lib/ld
$CP $FROM/usr/local/lib/libbfd.a  $TO/lib/libbfd.a
$CP $FROM/usr/local/lib/libbsd-compat.a  $TO/lib/libbsd-compat.a
$CP $FROM/usr/local/lib/libc.a  $TO/lib/libc.a
$CP $FROM/usr/local/lib/libfl.a  $TO/lib/libfl.a
$CP $FROM/usr/local/lib/libgdbm.a  $TO/lib/libgdbm.a
$CP $FROM/usr/local/lib/libgmp.a  $TO/lib/libgmp.a
$CP $FROM/usr/local/lib/libiberty.a  $TO/lib/libiberty.a
$CP $FROM/usr/local/lib/libm.a  $TO/lib/libm.a
$CP $FROM/usr/local/lib/libmcheck.a  $TO/lib/libmcheck.a
$CP $FROM/usr/local/lib/libmmalloc.a  $TO/lib/libmmalloc.a
$CP $FROM/usr/local/lib/libmp.a  $TO/lib/libmp.a
$CP $FROM/usr/local/lib/libopcodes.a  $TO/lib/libopcodes.a
$CP $FROM/usr/local/lib/libposix.a  $TO/lib/libposix.a
$CP $FROM/usr/local/lib/libreadline.a  $TO/lib/libreadline.a
$CP $FROM/usr/local/lib/libtermcap.a  $TO/lib/libtermcap.a
if test ! -d $TO/lib/locate; then mkdir -p $TO/lib/locate; fi
$CP $FROM/usr/local/lib/locate/bigram  $TO/lib/locate/bigram
$CP $FROM/usr/local/lib/locate/code  $TO/lib/locate/code
$CP $FROM/usr/local/lib/locate/updatedb  $TO/lib/locate/updatedb
if test ! -d $TO/lib/perl; then mkdir -p $TO/lib/perl; fi
$CP $FROM/usr/local/lib/perl/abbrev.pl  $TO/lib/perl/abbrev.pl
$CP $FROM/usr/local/lib/perl/assert.pl  $TO/lib/perl/assert.pl
$CP $FROM/usr/local/lib/perl/bigfloat.pl  $TO/lib/perl/bigfloat.pl
$CP $FROM/usr/local/lib/perl/bigint.pl  $TO/lib/perl/bigint.pl
$CP $FROM/usr/local/lib/perl/bigrat.pl  $TO/lib/perl/bigrat.pl
$CP $FROM/usr/local/lib/perl/cacheout.pl  $TO/lib/perl/cacheout.pl
$CP $FROM/usr/local/lib/perl/chat2.pl  $TO/lib/perl/chat2.pl
$CP $FROM/usr/local/lib/perl/complete.pl  $TO/lib/perl/complete.pl
$CP $FROM/usr/local/lib/perl/ctime.pl  $TO/lib/perl/ctime.pl
$CP $FROM/usr/local/lib/perl/dumpvar.pl  $TO/lib/perl/dumpvar.pl
$CP $FROM/usr/local/lib/perl/exceptions.pl  $TO/lib/perl/exceptions.pl
$CP $FROM/usr/local/lib/perl/fastcwd.pl  $TO/lib/perl/fastcwd.pl
$CP $FROM/usr/local/lib/perl/find.pl  $TO/lib/perl/find.pl
$CP $FROM/usr/local/lib/perl/finddepth.pl  $TO/lib/perl/finddepth.pl
$CP $FROM/usr/local/lib/perl/flush.pl  $TO/lib/perl/flush.pl
$CP $FROM/usr/local/lib/perl/getcwd.pl  $TO/lib/perl/getcwd.pl
$CP $FROM/usr/local/lib/perl/getopt.pl  $TO/lib/perl/getopt.pl
$CP $FROM/usr/local/lib/perl/getopts.pl  $TO/lib/perl/getopts.pl
$CP $FROM/usr/local/lib/perl/importenv.pl  $TO/lib/perl/importenv.pl
$CP $FROM/usr/local/lib/perl/look.pl  $TO/lib/perl/look.pl
$CP $FROM/usr/local/lib/perl/newgetopt.pl  $TO/lib/perl/newgetopt.pl
$CP $FROM/usr/local/lib/perl/open2.pl  $TO/lib/perl/open2.pl
$CP $FROM/usr/local/lib/perl/perldb.pl  $TO/lib/perl/perldb.pl
$CP $FROM/usr/local/lib/perl/pwd.pl  $TO/lib/perl/pwd.pl
$CP $FROM/usr/local/lib/perl/shellwords.pl  $TO/lib/perl/shellwords.pl
$CP $FROM/usr/local/lib/perl/stat.pl  $TO/lib/perl/stat.pl
$CP $FROM/usr/local/lib/perl/syslog.pl  $TO/lib/perl/syslog.pl
$CP $FROM/usr/local/lib/perl/termcap.pl  $TO/lib/perl/termcap.pl
$CP $FROM/usr/local/lib/perl/timelocal.pl  $TO/lib/perl/timelocal.pl
$CP $FROM/usr/local/lib/perl/validate.pl  $TO/lib/perl/validate.pl
$CP $FROM/usr/local/lib/screenrc  $TO/lib/screenrc
if test ! -d $TO/lib/uucp; then mkdir -p $TO/lib/uucp; fi
$CP $FROM/usr/local/lib/uucp/uuchk  $TO/lib/uucp/uuchk
$CP $FROM/usr/local/lib/uucp/uucico  $TO/lib/uucp/uucico
$CP $FROM/usr/local/lib/uucp/uucico.old  $TO/lib/uucp/uucico.old
$CP $FROM/usr/local/lib/uucp/uuxqt  $TO/lib/uucp/uuxqt
$CP $FROM/usr/local/lib/uucp/uuxqt.old  $TO/lib/uucp/uuxqt.old
if test ! -d $TO/man; then mkdir -p $TO/man; fi
if test ! -d $TO/man/man1; then mkdir -p $TO/man/man1; fi
$CP $FROM/usr/local/man/man1/ar.1  $TO/man/man1/ar.1
$CP $FROM/usr/local/man/man1/basename.1  $TO/man/man1/basename.1
$CP $FROM/usr/local/man/man1/bc.1  $TO/man/man1/bc.1
$CP $FROM/usr/local/man/man1/bison.1  $TO/man/man1/bison.1
$CP $FROM/usr/local/man/man1/cat.1  $TO/man/man1/cat.1
$CP $FROM/usr/local/man/man1/cccp.1  $TO/man/man1/cccp.1
$CP $FROM/usr/local/man/man1/chgrp.1  $TO/man/man1/chgrp.1
$CP $FROM/usr/local/man/man1/chmod.1  $TO/man/man1/chmod.1
$CP $FROM/usr/local/man/man1/chown.1  $TO/man/man1/chown.1
$CP $FROM/usr/local/man/man1/ci.1  $TO/man/man1/ci.1
$CP $FROM/usr/local/man/man1/cmp.1  $TO/man/man1/cmp.1
$CP $FROM/usr/local/man/man1/co.1  $TO/man/man1/co.1
$CP $FROM/usr/local/man/man1/comm.1  $TO/man/man1/comm.1
$CP $FROM/usr/local/man/man1/cp.1  $TO/man/man1/cp.1
$CP $FROM/usr/local/man/man1/cpio.1  $TO/man/man1/cpio.1
$CP $FROM/usr/local/man/man1/csplit.1  $TO/man/man1/csplit.1
$CP $FROM/usr/local/man/man1/cut.1  $TO/man/man1/cut.1
$CP $FROM/usr/local/man/man1/cvs.1  $TO/man/man1/cvs.1
$CP $FROM/usr/local/man/man1/date.1  $TO/man/man1/date.1
$CP $FROM/usr/local/man/man1/dd.1  $TO/man/man1/dd.1
$CP $FROM/usr/local/man/man1/df.1  $TO/man/man1/df.1
$CP $FROM/usr/local/man/man1/dirname.1  $TO/man/man1/dirname.1
$CP $FROM/usr/local/man/man1/du.1  $TO/man/man1/du.1
$CP $FROM/usr/local/man/man1/echo.1  $TO/man/man1/echo.1
$CP $FROM/usr/local/man/man1/emacs.1  $TO/man/man1/emacs.1
$CP $FROM/usr/local/man/man1/env.1  $TO/man/man1/env.1
$CP $FROM/usr/local/man/man1/expand.1  $TO/man/man1/expand.1
$CP $FROM/usr/local/man/man1/expr.1  $TO/man/man1/expr.1
$CP $FROM/usr/local/man/man1/f2c.1  $TO/man/man1/f2c.1
$CP $FROM/usr/local/man/man1/false.1  $TO/man/man1/false.1
$CP $FROM/usr/local/man/man1/find.1  $TO/man/man1/find.1
$CP $FROM/usr/local/man/man1/fold.1  $TO/man/man1/fold.1
$CP $FROM/usr/local/man/man1/g++.1  $TO/man/man1/g++.1
$CP $FROM/usr/local/man/man1/gawk.1  $TO/man/man1/gawk.1
$CP $FROM/usr/local/man/man1/gcc.1  $TO/man/man1/gcc.1
$CP $FROM/usr/local/man/man1/gdb.1  $TO/man/man1/gdb.1
$CP $FROM/usr/local/man/man1/gprof.1  $TO/man/man1/gprof.1
$CP $FROM/usr/local/man/man1/grep.1  $TO/man/man1/grep.1
$CP $FROM/usr/local/man/man1/groups.1  $TO/man/man1/groups.1
$CP $FROM/usr/local/man/man1/head.1  $TO/man/man1/head.1
$CP $FROM/usr/local/man/man1/id.1  $TO/man/man1/id.1
$CP $FROM/usr/local/man/man1/ident.1  $TO/man/man1/ident.1
$CP $FROM/usr/local/man/man1/install.1  $TO/man/man1/install.1
$CP $FROM/usr/local/man/man1/join.1  $TO/man/man1/join.1
$CP $FROM/usr/local/man/man1/ld.1  $TO/man/man1/ld.1
$CP $FROM/usr/local/man/man1/less.1  $TO/man/man1/less.1
$CP $FROM/usr/local/man/man1/lesskey.1  $TO/man/man1/lesskey.1
$CP $FROM/usr/local/man/man1/ln.1  $TO/man/man1/ln.1
$CP $FROM/usr/local/man/man1/locate.1  $TO/man/man1/locate.1
$CP $FROM/usr/local/man/man1/logname.1  $TO/man/man1/logname.1
$CP $FROM/usr/local/man/man1/ls.1  $TO/man/man1/ls.1
$CP $FROM/usr/local/man/man1/mattrib.1  $TO/man/man1/mattrib.1
$CP $FROM/usr/local/man/man1/mcd.1  $TO/man/man1/mcd.1
$CP $FROM/usr/local/man/man1/mcopy.1  $TO/man/man1/mcopy.1
$CP $FROM/usr/local/man/man1/mdel.1  $TO/man/man1/mdel.1
$CP $FROM/usr/local/man/man1/mdir.1  $TO/man/man1/mdir.1
$CP $FROM/usr/local/man/man1/merge.1  $TO/man/man1/merge.1
$CP $FROM/usr/local/man/man1/mformat.1  $TO/man/man1/mformat.1
$CP $FROM/usr/local/man/man1/mkdir.1  $TO/man/man1/mkdir.1
$CP $FROM/usr/local/man/man1/mkfifo.1  $TO/man/man1/mkfifo.1
$CP $FROM/usr/local/man/man1/mkmanifest.1  $TO/man/man1/mkmanifest.1
$CP $FROM/usr/local/man/man1/mkmodules.1  $TO/man/man1/mkmodules.1
$CP $FROM/usr/local/man/man1/mknod.1  $TO/man/man1/mknod.1
$CP $FROM/usr/local/man/man1/mlabel.1  $TO/man/man1/mlabel.1
$CP $FROM/usr/local/man/man1/mmd.1  $TO/man/man1/mmd.1
$CP $FROM/usr/local/man/man1/mrd.1  $TO/man/man1/mrd.1
$CP $FROM/usr/local/man/man1/mread.1  $TO/man/man1/mread.1
$CP $FROM/usr/local/man/man1/mren.1  $TO/man/man1/mren.1
$CP $FROM/usr/local/man/man1/mt.1  $TO/man/man1/mt.1
$CP $FROM/usr/local/man/man1/mtools.1  $TO/man/man1/mtools.1
$CP $FROM/usr/local/man/man1/mtype.1  $TO/man/man1/mtype.1
$CP $FROM/usr/local/man/man1/mv.1  $TO/man/man1/mv.1
$CP $FROM/usr/local/man/man1/mwrite.1  $TO/man/man1/mwrite.1
$CP $FROM/usr/local/man/man1/nice.1  $TO/man/man1/nice.1
$CP $FROM/usr/local/man/man1/nl.1  $TO/man/man1/nl.1
$CP $FROM/usr/local/man/man1/nm.1  $TO/man/man1/nm.1
$CP $FROM/usr/local/man/man1/nohup.1  $TO/man/man1/nohup.1
$CP $FROM/usr/local/man/man1/objdump.1  $TO/man/man1/objdump.1
$CP $FROM/usr/local/man/man1/paste.1  $TO/man/man1/paste.1
$CP $FROM/usr/local/man/man1/patch.1  $TO/man/man1/patch.1
$CP $FROM/usr/local/man/man1/pathchk.1  $TO/man/man1/pathchk.1
$CP $FROM/usr/local/man/man1/plot2fig.1  $TO/man/man1/plot2fig.1
$CP $FROM/usr/local/man/man1/plot2ps.1  $TO/man/man1/plot2ps.1
$CP $FROM/usr/local/man/man1/pr.1  $TO/man/man1/pr.1
$CP $FROM/usr/local/man/man1/printenv.1  $TO/man/man1/printenv.1
$CP $FROM/usr/local/man/man1/printf.1  $TO/man/man1/printf.1
$CP $FROM/usr/local/man/man1/ranlib.1  $TO/man/man1/ranlib.1
$CP $FROM/usr/local/man/man1/rcs.1  $TO/man/man1/rcs.1
$CP $FROM/usr/local/man/man1/rcsdiff.1  $TO/man/man1/rcsdiff.1
$CP $FROM/usr/local/man/man1/rcsintro.1  $TO/man/man1/rcsintro.1
$CP $FROM/usr/local/man/man1/rcsmerge.1  $TO/man/man1/rcsmerge.1
$CP $FROM/usr/local/man/man1/rlog.1  $TO/man/man1/rlog.1
$CP $FROM/usr/local/man/man1/rm.1  $TO/man/man1/rm.1
$CP $FROM/usr/local/man/man1/rmdir.1  $TO/man/man1/rmdir.1
$CP $FROM/usr/local/man/man1/screen.1  $TO/man/man1/screen.1
$CP $FROM/usr/local/man/man1/size.1  $TO/man/man1/size.1
$CP $FROM/usr/local/man/man1/sleep.1  $TO/man/man1/sleep.1
$CP $FROM/usr/local/man/man1/sort.1  $TO/man/man1/sort.1
$CP $FROM/usr/local/man/man1/split.1  $TO/man/man1/split.1
$CP $FROM/usr/local/man/man1/strip.1  $TO/man/man1/strip.1
$CP $FROM/usr/local/man/man1/stty.1  $TO/man/man1/stty.1
$CP $FROM/usr/local/man/man1/su.1  $TO/man/man1/su.1
$CP $FROM/usr/local/man/man1/sum.1  $TO/man/man1/sum.1
$CP $FROM/usr/local/man/man1/tac.1  $TO/man/man1/tac.1
$CP $FROM/usr/local/man/man1/tail.1  $TO/man/man1/tail.1
$CP $FROM/usr/local/man/man1/tee.1  $TO/man/man1/tee.1
$CP $FROM/usr/local/man/man1/test.1  $TO/man/man1/test.1
$CP $FROM/usr/local/man/man1/touch.1  $TO/man/man1/touch.1
$CP $FROM/usr/local/man/man1/tr.1  $TO/man/man1/tr.1
$CP $FROM/usr/local/man/man1/true.1  $TO/man/man1/true.1
$CP $FROM/usr/local/man/man1/tty.1  $TO/man/man1/tty.1
$CP $FROM/usr/local/man/man1/uname.1  $TO/man/man1/uname.1
$CP $FROM/usr/local/man/man1/unexpand.1  $TO/man/man1/unexpand.1
$CP $FROM/usr/local/man/man1/uniq.1  $TO/man/man1/uniq.1
$CP $FROM/usr/local/man/man1/uucp.1  $TO/man/man1/uucp.1
$CP $FROM/usr/local/man/man1/uux.1  $TO/man/man1/uux.1
$CP $FROM/usr/local/man/man1/wc.1  $TO/man/man1/wc.1
$CP $FROM/usr/local/man/man1/who.1  $TO/man/man1/who.1
$CP $FROM/usr/local/man/man1/whoami.1  $TO/man/man1/whoami.1
$CP $FROM/usr/local/man/man1/xargs.1  $TO/man/man1/xargs.1
$CP $FROM/usr/local/man/man1/xplot.1  $TO/man/man1/xplot.1
$CP $FROM/usr/local/man/man1/yes.1  $TO/man/man1/yes.1
if test ! -d $TO/man/man5; then mkdir -p $TO/man/man5; fi
$CP $FROM/usr/local/man/man5/cvs.5  $TO/man/man5/cvs.5
$CP $FROM/usr/local/man/man5/rcsfile.5  $TO/man/man5/rcsfile.5
if test ! -d $TO/man/man8; then mkdir -p $TO/man/man8; fi
$CP $FROM/usr/local/man/man8/uucico.8  $TO/man/man8/uucico.8
$CP $FROM/usr/local/man/man8/uuxqt.8  $TO/man/man8/uuxqt.8
if test ! -d $TO/man/manl; then mkdir -p $TO/man/manl; fi
$CP $FROM/usr/local/man/manl/a2p.l  $TO/man/manl/a2p.l
$CP $FROM/usr/local/man/manl/flex.l  $TO/man/manl/flex.l
$CP $FROM/usr/local/man/manl/flexdoc.l  $TO/man/manl/flexdoc.l
$CP $FROM/usr/local/man/manl/gnuplot.1  $TO/man/manl/gnuplot.1
$CP $FROM/usr/local/man/manl/h2ph.l  $TO/man/manl/h2ph.l
$CP $FROM/usr/local/man/manl/ispell.1l  $TO/man/manl/ispell.1l
$CP $FROM/usr/local/man/manl/ispell.4l  $TO/man/manl/ispell.4l
$CP $FROM/usr/local/man/manl/lasergnu.1  $TO/man/manl/lasergnu.1
$CP $FROM/usr/local/man/manl/make.l  $TO/man/manl/make.l
$CP $FROM/usr/local/man/manl/perl.l  $TO/man/manl/perl.l
$CP $FROM/usr/local/man/manl/s2p.l  $TO/man/manl/s2p.l
if test ! -d $TO/mtools; then mkdir -p $TO/mtools; fi
$CP $FROM/usr/local/mtools/mattrib  $TO/mtools/mattrib
$CP $FROM/usr/local/mtools/mcd  $TO/mtools/mcd
$CP $FROM/usr/local/mtools/mcopy  $TO/mtools/mcopy
$CP $FROM/usr/local/mtools/mdel  $TO/mtools/mdel
$CP $FROM/usr/local/mtools/mdir  $TO/mtools/mdir
$CP $FROM/usr/local/mtools/mformat  $TO/mtools/mformat
$CP $FROM/usr/local/mtools/mkmanifest  $TO/mtools/mkmanifest
$CP $FROM/usr/local/mtools/mlabel  $TO/mtools/mlabel
$CP $FROM/usr/local/mtools/mmd  $TO/mtools/mmd
$CP $FROM/usr/local/mtools/mrd  $TO/mtools/mrd
$CP $FROM/usr/local/mtools/mread  $TO/mtools/mread
$CP $FROM/usr/local/mtools/mren  $TO/mtools/mren
$CP $FROM/usr/local/mtools/mtype  $TO/mtools/mtype
$CP $FROM/usr/local/mtools/mwrite  $TO/mtools/mwrite
if test ! -d $TO/smalltalk; then mkdir -p $TO/smalltalk; fi
$CP $FROM/usr/local/smalltalk/Array.st  $TO/smalltalk/Array.st
$CP $FROM/usr/local/smalltalk/ArrayedCollection.st  $TO/smalltalk/ArrayedCollection.st
$CP $FROM/usr/local/smalltalk/Association.st  $TO/smalltalk/Association.st
$CP $FROM/usr/local/smalltalk/Autoload.st  $TO/smalltalk/Autoload.st
$CP $FROM/usr/local/smalltalk/Bag.st  $TO/smalltalk/Bag.st
$CP $FROM/usr/local/smalltalk/Behavior.st  $TO/smalltalk/Behavior.st
$CP $FROM/usr/local/smalltalk/BlockContext.st  $TO/smalltalk/BlockContext.st
$CP $FROM/usr/local/smalltalk/Boolean.st  $TO/smalltalk/Boolean.st
$CP $FROM/usr/local/smalltalk/ByteArray.st  $TO/smalltalk/ByteArray.st
$CP $FROM/usr/local/smalltalk/ByteMemory.st  $TO/smalltalk/ByteMemory.st
$CP $FROM/usr/local/smalltalk/CFuncs.st  $TO/smalltalk/CFuncs.st
$CP $FROM/usr/local/smalltalk/Character.st  $TO/smalltalk/Character.st
$CP $FROM/usr/local/smalltalk/Class.st  $TO/smalltalk/Class.st
$CP $FROM/usr/local/smalltalk/ClassDescription.st  $TO/smalltalk/ClassDescription.st
$CP $FROM/usr/local/smalltalk/Collection.st  $TO/smalltalk/Collection.st
$CP $FROM/usr/local/smalltalk/CompiledMethod.st  $TO/smalltalk/CompiledMethod.st
$CP $FROM/usr/local/smalltalk/Date.st  $TO/smalltalk/Date.st
$CP $FROM/usr/local/smalltalk/Debugger.st  $TO/smalltalk/Debugger.st
$CP $FROM/usr/local/smalltalk/Delay.st  $TO/smalltalk/Delay.st
$CP $FROM/usr/local/smalltalk/Dictionary.st  $TO/smalltalk/Dictionary.st
$CP $FROM/usr/local/smalltalk/False.st  $TO/smalltalk/False.st
$CP $FROM/usr/local/smalltalk/FileSegment.st  $TO/smalltalk/FileSegment.st
$CP $FROM/usr/local/smalltalk/FileStream.st  $TO/smalltalk/FileStream.st
$CP $FROM/usr/local/smalltalk/Float.st  $TO/smalltalk/Float.st
$CP $FROM/usr/local/smalltalk/IdentityDictionary.st  $TO/smalltalk/IdentityDictionary.st
$CP $FROM/usr/local/smalltalk/Integer.st  $TO/smalltalk/Integer.st
$CP $FROM/usr/local/smalltalk/Interval.st  $TO/smalltalk/Interval.st
$CP $FROM/usr/local/smalltalk/Link.st  $TO/smalltalk/Link.st
$CP $FROM/usr/local/smalltalk/LinkedList.st  $TO/smalltalk/LinkedList.st
$CP $FROM/usr/local/smalltalk/LookupKey.st  $TO/smalltalk/LookupKey.st
$CP $FROM/usr/local/smalltalk/Magnitude.st  $TO/smalltalk/Magnitude.st
$CP $FROM/usr/local/smalltalk/MappedCollection.st  $TO/smalltalk/MappedCollection.st
$CP $FROM/usr/local/smalltalk/Memory.st  $TO/smalltalk/Memory.st
$CP $FROM/usr/local/smalltalk/Message.st  $TO/smalltalk/Message.st
$CP $FROM/usr/local/smalltalk/Metaclass.st  $TO/smalltalk/Metaclass.st
$CP $FROM/usr/local/smalltalk/MethodContext.st  $TO/smalltalk/MethodContext.st
$CP $FROM/usr/local/smalltalk/MethodInfo.st  $TO/smalltalk/MethodInfo.st
$CP $FROM/usr/local/smalltalk/Number.st  $TO/smalltalk/Number.st
$CP $FROM/usr/local/smalltalk/Object.st  $TO/smalltalk/Object.st
$CP $FROM/usr/local/smalltalk/OrderedCollection.st  $TO/smalltalk/OrderedCollection.st
$CP $FROM/usr/local/smalltalk/PositionableStream.st  $TO/smalltalk/PositionableStream.st
$CP $FROM/usr/local/smalltalk/Process.st  $TO/smalltalk/Process.st
$CP $FROM/usr/local/smalltalk/ProcessorScheduler.st  $TO/smalltalk/ProcessorScheduler.st
$CP $FROM/usr/local/smalltalk/Random.st  $TO/smalltalk/Random.st
$CP $FROM/usr/local/smalltalk/ReadStream.st  $TO/smalltalk/ReadStream.st
$CP $FROM/usr/local/smalltalk/ReadWriteStream.st  $TO/smalltalk/ReadWriteStream.st
$CP $FROM/usr/local/smalltalk/Semaphore.st  $TO/smalltalk/Semaphore.st
$CP $FROM/usr/local/smalltalk/SequenceableCollection.st  $TO/smalltalk/SequenceableCollection.st
$CP $FROM/usr/local/smalltalk/Set.st  $TO/smalltalk/Set.st
$CP $FROM/usr/local/smalltalk/SharedQueue.st  $TO/smalltalk/SharedQueue.st
$CP $FROM/usr/local/smalltalk/SortedCollection.st  $TO/smalltalk/SortedCollection.st
$CP $FROM/usr/local/smalltalk/Stream.st  $TO/smalltalk/Stream.st
$CP $FROM/usr/local/smalltalk/String.st  $TO/smalltalk/String.st
$CP $FROM/usr/local/smalltalk/SymLink.st  $TO/smalltalk/SymLink.st
$CP $FROM/usr/local/smalltalk/Symbol.st  $TO/smalltalk/Symbol.st
$CP $FROM/usr/local/smalltalk/SystemDictionary.st  $TO/smalltalk/SystemDictionary.st
$CP $FROM/usr/local/smalltalk/Time.st  $TO/smalltalk/Time.st
$CP $FROM/usr/local/smalltalk/TokenStream.st  $TO/smalltalk/TokenStream.st
$CP $FROM/usr/local/smalltalk/True.st  $TO/smalltalk/True.st
$CP $FROM/usr/local/smalltalk/UndefinedObject.st  $TO/smalltalk/UndefinedObject.st
$CP $FROM/usr/local/smalltalk/WordMemory.st  $TO/smalltalk/WordMemory.st
$CP $FROM/usr/local/smalltalk/WriteStream.st  $TO/smalltalk/WriteStream.st
$CP $FROM/usr/local/smalltalk/builtins.st  $TO/smalltalk/builtins.st
$CP $FROM/usr/local/smalltalk/initialize.st  $TO/smalltalk/initialize.st
$CP $FROM/usr/local/smalltalk/t.st  $TO/smalltalk/t.st

exit 0
